'''
Copyright (c) 2020 epiphani, Inc.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
'''
# This is an auto-generated file, please do not modify

MUTATIONS = {'createalertapikey': '\n'
                      '  mutation CreateAlertApiKey($input: '
                      'CreateAlertApiKeyInput!) {\n'
                      '    createAlertApiKey(input: $input) {\n'
                      '      id\n'
                      '      alertsPbName\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '      author\n'
                      '    }\n'
                      '  }\n',
 'createallrunbooks': '\n'
                      '  mutation CreateAllRunbooks($input: '
                      'CreateAllRunbooksInput!) {\n'
                      '    createAllRunbooks(input: $input) {\n'
                      '      id\n'
                      '      name\n'
                      '      description\n'
                      '      content\n'
                      '      author\n'
                      '      commands\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '      RunBookConnectors\n'
                      '      type\n'
                      '      longSave\n'
                      '      rbVars\n'
                      '      scope\n'
                      '      PeopleCanView\n'
                      '      PeopleCanAccess\n'
                      '      GroupsCanView\n'
                      '      GroupsCanAccess\n'
                      '      connectorForms {\n'
                      '        nextToken\n'
                      '      }\n'
                      '    }\n'
                      '  }\n',
 'createallworkflows': '\n'
                       '  mutation CreateAllWorkflows($input: '
                       'CreateAllWorkflowsInput!) {\n'
                       '    createAllWorkflows(input: $input) {\n'
                       '      id\n'
                       '      createdAt\n'
                       '      updatedAt\n'
                       '      name\n'
                       '      description\n'
                       '      type\n'
                       '      author\n'
                       '      longSave\n'
                       '      rbVars\n'
                       '    }\n'
                       '  }\n',
 'createbase64image': '\n'
                      '  mutation CreateBase64Image($input: '
                      'CreateBase64ImageInput!) {\n'
                      '    createBase64Image(input: $input) {\n'
                      '      id\n'
                      '      playbookID\n'
                      '      base64String\n'
                      '    }\n'
                      '  }\n',
 'createchannel': '\n'
                  '  mutation CreateChannel($input: CreateChannelInput!) {\n'
                  '    createChannel(input: $input) {\n'
                  '      id\n'
                  '      messages {\n'
                  '        nextToken\n'
                  '      }\n'
                  '      associated {\n'
                  '        nextToken\n'
                  '      }\n'
                  '      name\n'
                  '      title\n'
                  '      members\n'
                  '      membersState\n'
                  '      createdAt\n'
                  '      updatedAt\n'
                  '      memberLocation\n'
                  '    }\n'
                  '  }\n',
 'createchannellink': '\n'
                      '  mutation CreateChannelLink($input: '
                      'CreateChannelLinkInput!) {\n'
                      '    createChannelLink(input: $input) {\n'
                      '      id\n'
                      '      contactId\n'
                      '      channel {\n'
                      '        id\n'
                      '        name\n'
                      '        title\n'
                      '        members\n'
                      '        membersState\n'
                      '        createdAt\n'
                      '        updatedAt\n'
                      '        memberLocation\n'
                      '      }\n'
                      '      chatId\n'
                      '      unread\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '      user {\n'
                      '        id\n'
                      '        username\n'
                      '        email\n'
                      '        firstname\n'
                      '        lastname\n'
                      '        avatar\n'
                      '        mood\n'
                      '        name\n'
                      '        role\n'
                      '        status\n'
                      '        timezone\n'
                      '        phone\n'
                      '        address\n'
                      '        location\n'
                      '        createdAt\n'
                      '        updatedAt\n'
                      '        owner\n'
                      '      }\n'
                      '    }\n'
                      '  }\n',
 'createchat': '\n'
               '  mutation CreateChat($input: CreateChatInput!) {\n'
               '    createChat(input: $input) {\n'
               '      id\n'
               '      from\n'
               '      content\n'
               '      createdAt\n'
               '    }\n'
               '  }\n',
 'createcheatsheet': '\n'
                     '  mutation CreateCheatSheet($input: '
                     'CreateCheatSheetInput!) {\n'
                     '    createCheatSheet(input: $input) {\n'
                     '      id\n'
                     '      createdAt\n'
                     '      updatedAt\n'
                     '      title\n'
                     '      author\n'
                     '      content\n'
                     '      type\n'
                     '    }\n'
                     '  }\n',
 'createchecklist': '\n'
                    '  mutation CreateCheckList($input: CreateCheckListInput!) '
                    '{\n'
                    '    createCheckList(input: $input) {\n'
                    '      id\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '      name\n'
                    '      description\n'
                    '      type\n'
                    '      content\n'
                    '      author\n'
                    '      CheckListLink {\n'
                    '        nextToken\n'
                    '      }\n'
                    '      CheckListInvLink {\n'
                    '        nextToken\n'
                    '      }\n'
                    '    }\n'
                    '  }\n',
 'createchecklistinvlink': '\n'
                           '  mutation CreateCheckListInvLink($input: '
                           'CreateCheckListInvLinkInput!) {\n'
                           '    createCheckListInvLink(input: $input) {\n'
                           '      id\n'
                           '      createdAt\n'
                           '      updatedAt\n'
                           '      investigationID\n'
                           '      CheckListID\n'
                           '      CheckList {\n'
                           '        id\n'
                           '        createdAt\n'
                           '        updatedAt\n'
                           '        name\n'
                           '        description\n'
                           '        type\n'
                           '        content\n'
                           '        author\n'
                           '      }\n'
                           '      investigation {\n'
                           '        id\n'
                           '        title\n'
                           '        from\n'
                           '        createdAt\n'
                           '        currentState\n'
                           '        HumanID\n'
                           '        currentStateID\n'
                           '        severity\n'
                           '        priority\n'
                           '        location\n'
                           '        channelId\n'
                           '        updatedAt\n'
                           '        resolvedTime\n'
                           '        resolvedComment\n'
                           '        Symptoms\n'
                           '        meetingType\n'
                           '        meetingId\n'
                           '      }\n'
                           '      owner\n'
                           '    }\n'
                           '  }\n',
 'createchecklistitem': '\n'
                        '  mutation CreateCheckListItem($input: '
                        'CreateCheckListItemInput!) {\n'
                        '    createCheckListItem(input: $input) {\n'
                        '      id\n'
                        '      localID\n'
                        '      createdAt\n'
                        '      updatedAt\n'
                        '      author\n'
                        '      content\n'
                        '      title\n'
                        '      type\n'
                        '      connection\n'
                        '      MMNodeConnection\n'
                        '      investigationID\n'
                        '      assignee\n'
                        '      associatedPlaybooks\n'
                        '      associatedCommands\n'
                        '      CheckListLink {\n'
                        '        nextToken\n'
                        '      }\n'
                        '    }\n'
                        '  }\n',
 'createclick': '\n'
                '  mutation CreateClick($input: CreateClickInput!) {\n'
                '    createClick(input: $input) {\n'
                '      id\n'
                '      count\n'
                '      type\n'
                '      featureName\n'
                '      createdAt\n'
                '      updatedAt\n'
                '      readAt\n'
                '    }\n'
                '  }\n',
 'createclicllink': '\n'
                    '  mutation CreateCliclLink($input: CreateCLICLLinkInput!) '
                    '{\n'
                    '    createCLICLLink(input: $input) {\n'
                    '      id\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '      CheckListItemID\n'
                    '      lane\n'
                    '      CheckListID\n'
                    '      CheckList {\n'
                    '        id\n'
                    '        createdAt\n'
                    '        updatedAt\n'
                    '        name\n'
                    '        description\n'
                    '        type\n'
                    '        content\n'
                    '        author\n'
                    '      }\n'
                    '      CheckListItem {\n'
                    '        id\n'
                    '        localID\n'
                    '        createdAt\n'
                    '        updatedAt\n'
                    '        author\n'
                    '        content\n'
                    '        title\n'
                    '        type\n'
                    '        connection\n'
                    '        MMNodeConnection\n'
                    '        investigationID\n'
                    '        assignee\n'
                    '        associatedPlaybooks\n'
                    '        associatedCommands\n'
                    '      }\n'
                    '    }\n'
                    '  }\n',
 'createcommands': '\n'
                   '  mutation CreateCommands($input: CreateCommandsInput!) {\n'
                   '    createCommands(input: $input) {\n'
                   '      id\n'
                   '      from\n'
                   '      mode\n'
                   '      command\n'
                   '      output\n'
                   '      state\n'
                   '      returnCode\n'
                   '      investigationId\n'
                   '      createdAt\n'
                   '      updatedAt\n'
                   '      investigation {\n'
                   '        id\n'
                   '        title\n'
                   '        from\n'
                   '        createdAt\n'
                   '        currentState\n'
                   '        HumanID\n'
                   '        currentStateID\n'
                   '        severity\n'
                   '        priority\n'
                   '        location\n'
                   '        channelId\n'
                   '        updatedAt\n'
                   '        resolvedTime\n'
                   '        resolvedComment\n'
                   '        Symptoms\n'
                   '        meetingType\n'
                   '        meetingId\n'
                   '      }\n'
                   '    }\n'
                   '  }\n',
 'createcomment': '\n'
                  '  mutation CreateComment($input: CreateCommentInput!) {\n'
                  '    createComment(input: $input) {\n'
                  '      id\n'
                  '      parent\n'
                  '      createdAt\n'
                  '      updatedAt\n'
                  '      author\n'
                  '      content\n'
                  '      type\n'
                  '      links\n'
                  '      investigationId\n'
                  '      investigation {\n'
                  '        id\n'
                  '        title\n'
                  '        from\n'
                  '        createdAt\n'
                  '        currentState\n'
                  '        HumanID\n'
                  '        currentStateID\n'
                  '        severity\n'
                  '        priority\n'
                  '        location\n'
                  '        channelId\n'
                  '        updatedAt\n'
                  '        resolvedTime\n'
                  '        resolvedComment\n'
                  '        Symptoms\n'
                  '        meetingType\n'
                  '        meetingId\n'
                  '      }\n'
                  '    }\n'
                  '  }\n',
 'createconferenceconfig': '\n'
                           '  mutation CreateConferenceConfig($input: '
                           'CreateConferenceConfigInput!) {\n'
                           '    createConferenceConfig(input: $input) {\n'
                           '      id\n'
                           '      url\n'
                           '      userName\n'
                           '      password\n'
                           '      author\n'
                           '      createdAt\n'
                           '      updatedAt\n'
                           '    }\n'
                           '  }\n',
 'createconnectorform': '\n'
                        '  mutation CreateConnectorForm($input: '
                        'CreateConnectorFormInput!) {\n'
                        '    createConnectorForm(input: $input) {\n'
                        '      id\n'
                        '      createdAt\n'
                        '      updatedAt\n'
                        '      name\n'
                        '      owner\n'
                        '      connectorID\n'
                        '      connector {\n'
                        '        id\n'
                        '        createdAt\n'
                        '        updatedAt\n'
                        '        category\n'
                        '        name\n'
                        '        owner\n'
                        '        description\n'
                        '        detaileddescription\n'
                        '        iconPath\n'
                        '        version\n'
                        '        md5\n'
                        '        source\n'
                        '        configuration\n'
                        '        commands\n'
                        '        commandsType\n'
                        '        script\n'
                        '        scriptType\n'
                        '        scriptPath\n'
                        '        scope\n'
                        '        PeopleCanView\n'
                        '        PeopleCanAccess\n'
                        '        GroupsCanView\n'
                        '        GroupsCanAccess\n'
                        '      }\n'
                        '      configData\n'
                        '      commandData\n'
                        '      nodeData\n'
                        '      scope\n'
                        '      PeopleCanView\n'
                        '      PeopleCanAccess\n'
                        '      GroupsCanView\n'
                        '      GroupsCanAccess\n'
                        '      runbooks {\n'
                        '        nextToken\n'
                        '      }\n'
                        '    }\n'
                        '  }\n',
 'createconnectors': '\n'
                     '  mutation CreateConnectors($input: '
                     'CreateConnectorsInput!) {\n'
                     '    createConnectors(input: $input) {\n'
                     '      id\n'
                     '      createdAt\n'
                     '      updatedAt\n'
                     '      category\n'
                     '      name\n'
                     '      owner\n'
                     '      description\n'
                     '      detaileddescription\n'
                     '      iconPath\n'
                     '      version\n'
                     '      md5\n'
                     '      source\n'
                     '      configuration\n'
                     '      commands\n'
                     '      commandsType\n'
                     '      script\n'
                     '      scriptType\n'
                     '      scriptPath\n'
                     '      scope\n'
                     '      PeopleCanView\n'
                     '      PeopleCanAccess\n'
                     '      GroupsCanView\n'
                     '      GroupsCanAccess\n'
                     '    }\n'
                     '  }\n',
 'createdashboardconfig': '\n'
                          '  mutation CreateDashboardConfig($input: '
                          'CreateDashboardConfigInput!) {\n'
                          '    createDashboardConfig(input: $input) {\n'
                          '      id\n'
                          '      url\n'
                          '      labels {\n'
                          '        nextToken\n'
                          '      }\n'
                          '      author\n'
                          '      createdAt\n'
                          '      updatedAt\n'
                          '    }\n'
                          '  }\n',
 'createdashboardconfiglabellink': '\n'
                                   '  mutation '
                                   'CreateDashboardConfigLabelLink(\n'
                                   '    $input: '
                                   'CreateDashboardConfigLabelLinkInput!\n'
                                   '  ) {\n'
                                   '    createDashboardConfigLabelLink(input: '
                                   '$input) {\n'
                                   '      id\n'
                                   '      dashboardConfigID\n'
                                   '      labelID\n'
                                   '      dashboardConfig {\n'
                                   '        id\n'
                                   '        url\n'
                                   '        author\n'
                                   '        createdAt\n'
                                   '        updatedAt\n'
                                   '      }\n'
                                   '      label {\n'
                                   '        id\n'
                                   '        name\n'
                                   '        color\n'
                                   '        type\n'
                                   '      }\n'
                                   '    }\n'
                                   '  }\n',
 'createecubesandboxexecution': '\n'
                                '  mutation CreateEcubeSandboxExecution(\n'
                                '    $input: '
                                'CreateEcubeSandboxExecutionInput!\n'
                                '  ) {\n'
                                '    createEcubeSandboxExecution(input: '
                                '$input) {\n'
                                '      id\n'
                                '      owner\n'
                                '      output\n'
                                '      outputType\n'
                                '      returnCode\n'
                                '      status\n'
                                '      createdAt\n'
                                '      updatedAt\n'
                                '      E3One\n'
                                '      E3Two\n'
                                '      E3Three\n'
                                '    }\n'
                                '  }\n',
 'createepicautocomplete': '\n'
                           '  mutation CreateEpicAutoComplete($input: '
                           'CreateEpicAutoCompleteInput!) {\n'
                           '    createEpicAutoComplete(input: $input) {\n'
                           '      id\n'
                           '      author\n'
                           '      cliCommand\n'
                           '      command\n'
                           '      createdAt\n'
                           '      updatedAt\n'
                           '      investigationId\n'
                           '      times\n'
                           '    }\n'
                           '  }\n',
 'createepiclicommand': '\n'
                        '  mutation CreateEpicliCommand($input: '
                        'CreateEPICLICommandInput!) {\n'
                        '    createEPICLICommand(input: $input) {\n'
                        '      id\n'
                        '      createdAt\n'
                        '      updatedAt\n'
                        '      author\n'
                        '      content\n'
                        '      type\n'
                        '    }\n'
                        '  }\n',
 'createexecutedrunbooks': '\n'
                           '  mutation CreateExecutedRunbooks($input: '
                           'CreateExecutedRunbooksInput!) {\n'
                           '    createExecutedRunbooks(input: $input) {\n'
                           '      id\n'
                           '      createdAt\n'
                           '      updatedAt\n'
                           '      runbookID\n'
                           '      investigationId\n'
                           '      output\n'
                           '      outputType\n'
                           '      title\n'
                           '      state\n'
                           '      author\n'
                           '      rbVars\n'
                           '      callbackUrl\n'
                           '      callbackData\n'
                           '      source\n'
                           '      investigation {\n'
                           '        id\n'
                           '        title\n'
                           '        from\n'
                           '        createdAt\n'
                           '        currentState\n'
                           '        HumanID\n'
                           '        currentStateID\n'
                           '        severity\n'
                           '        priority\n'
                           '        location\n'
                           '        channelId\n'
                           '        updatedAt\n'
                           '        resolvedTime\n'
                           '        resolvedComment\n'
                           '        Symptoms\n'
                           '        meetingType\n'
                           '        meetingId\n'
                           '      }\n'
                           '      runbook {\n'
                           '        id\n'
                           '        name\n'
                           '        description\n'
                           '        content\n'
                           '        author\n'
                           '        commands\n'
                           '        createdAt\n'
                           '        updatedAt\n'
                           '        RunBookConnectors\n'
                           '        type\n'
                           '        longSave\n'
                           '        rbVars\n'
                           '        scope\n'
                           '        PeopleCanView\n'
                           '        PeopleCanAccess\n'
                           '        GroupsCanView\n'
                           '        GroupsCanAccess\n'
                           '      }\n'
                           '    }\n'
                           '  }\n',
 'createexecutedworkflowstate': '\n'
                                '  mutation CreateExecutedWorkflowState(\n'
                                '    $input: '
                                'CreateExecutedWorkflowStateInput!\n'
                                '  ) {\n'
                                '    createExecutedWorkflowState(input: '
                                '$input) {\n'
                                '      id\n'
                                '      createdAt\n'
                                '      updatedAt\n'
                                '      name\n'
                                '      state\n'
                                '      output\n'
                                '      type\n'
                                '      allworkflowID\n'
                                '      investigationID\n'
                                '      investigation {\n'
                                '        id\n'
                                '        title\n'
                                '        from\n'
                                '        createdAt\n'
                                '        currentState\n'
                                '        HumanID\n'
                                '        currentStateID\n'
                                '        severity\n'
                                '        priority\n'
                                '        location\n'
                                '        channelId\n'
                                '        updatedAt\n'
                                '        resolvedTime\n'
                                '        resolvedComment\n'
                                '        Symptoms\n'
                                '        meetingType\n'
                                '        meetingId\n'
                                '      }\n'
                                '    }\n'
                                '  }\n',
 'creategroupmember': '\n'
                      '  mutation CreateGroupMember($input: '
                      'CreateGroupMemberInput!) {\n'
                      '    createGroupMember(input: $input) {\n'
                      '      id\n'
                      '      hostId\n'
                      '      groupId\n'
                      '      host {\n'
                      '        id\n'
                      '        inventoryId\n'
                      '        createdAt\n'
                      '        updatedAt\n'
                      '        author\n'
                      '        host\n'
                      '        port\n'
                      '        vars\n'
                      '      }\n'
                      '      group {\n'
                      '        id\n'
                      '        inventoryId\n'
                      '        createdAt\n'
                      '        updatedAt\n'
                      '        author\n'
                      '        name\n'
                      '        groups\n'
                      '        port\n'
                      '        vars\n'
                      '      }\n'
                      '    }\n'
                      '  }\n',
 'createguardrail': '\n'
                    '  mutation CreateGuardRail($input: CreateGuardRailInput!) '
                    '{\n'
                    '    createGuardRail(input: $input) {\n'
                    '      id\n'
                    '      timeOut\n'
                    '      message\n'
                    '      labels {\n'
                    '        nextToken\n'
                    '      }\n'
                    '      author\n'
                    '      active\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '    }\n'
                    '  }\n',
 'createguardraillabellink': '\n'
                             '  mutation CreateGuardRailLabelLink($input: '
                             'CreateGuardRailLabelLinkInput!) {\n'
                             '    createGuardRailLabelLink(input: $input) {\n'
                             '      id\n'
                             '      guardRailID\n'
                             '      labelID\n'
                             '      guardRail {\n'
                             '        id\n'
                             '        timeOut\n'
                             '        message\n'
                             '        author\n'
                             '        active\n'
                             '        createdAt\n'
                             '        updatedAt\n'
                             '      }\n'
                             '      label {\n'
                             '        id\n'
                             '        name\n'
                             '        color\n'
                             '        type\n'
                             '      }\n'
                             '    }\n'
                             '  }\n',
 'createhint': '\n'
               '  mutation CreateHint($input: CreateHintInput!) {\n'
               '    createHint(input: $input) {\n'
               '      id\n'
               '      investigationId\n'
               '      createdAt\n'
               '      updatedAt\n'
               '      type\n'
               '      connection\n'
               '      pastInvestigationID\n'
               '      title\n'
               '      importance\n'
               '      starrted\n'
               '      applied\n'
               '      url\n'
               '      why\n'
               '    }\n'
               '  }\n',
 'createinventory': '\n'
                    '  mutation CreateInventory($input: CreateInventoryInput!) '
                    '{\n'
                    '    createInventory(input: $input) {\n'
                    '      id\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '      author\n'
                    '      name\n'
                    '      all {\n'
                    '        nextToken\n'
                    '      }\n'
                    '      groups {\n'
                    '        nextToken\n'
                    '      }\n'
                    '      vars\n'
                    '    }\n'
                    '  }\n',
 'createinventorygroup': '\n'
                         '  mutation CreateInventoryGroup($input: '
                         'CreateInventoryGroupInput!) {\n'
                         '    createInventoryGroup(input: $input) {\n'
                         '      id\n'
                         '      inventoryId\n'
                         '      createdAt\n'
                         '      updatedAt\n'
                         '      author\n'
                         '      name\n'
                         '      hosts {\n'
                         '        nextToken\n'
                         '      }\n'
                         '      groups\n'
                         '      port\n'
                         '      vars\n'
                         '      inventory {\n'
                         '        id\n'
                         '        createdAt\n'
                         '        updatedAt\n'
                         '        author\n'
                         '        name\n'
                         '        vars\n'
                         '      }\n'
                         '    }\n'
                         '  }\n',
 'createinventoryhost': '\n'
                        '  mutation CreateInventoryHost($input: '
                        'CreateInventoryHostInput!) {\n'
                        '    createInventoryHost(input: $input) {\n'
                        '      id\n'
                        '      inventoryId\n'
                        '      createdAt\n'
                        '      updatedAt\n'
                        '      author\n'
                        '      host\n'
                        '      port\n'
                        '      vars\n'
                        '      groups {\n'
                        '        nextToken\n'
                        '      }\n'
                        '      inventory {\n'
                        '        id\n'
                        '        createdAt\n'
                        '        updatedAt\n'
                        '        author\n'
                        '        name\n'
                        '        vars\n'
                        '      }\n'
                        '    }\n'
                        '  }\n',
 'createinvestigation': '\n'
                        '  mutation CreateInvestigation($input: '
                        'CreateInvestigationInput!) {\n'
                        '    createInvestigation(input: $input) {\n'
                        '      id\n'
                        '      title\n'
                        '      from\n'
                        '      createdAt\n'
                        '      currentState\n'
                        '      HumanID\n'
                        '      currentStateID\n'
                        '      severity\n'
                        '      priority\n'
                        '      location\n'
                        '      labels {\n'
                        '        nextToken\n'
                        '      }\n'
                        '      channelId\n'
                        '      investigationChannel {\n'
                        '        id\n'
                        '        name\n'
                        '        title\n'
                        '        members\n'
                        '        membersState\n'
                        '        createdAt\n'
                        '        updatedAt\n'
                        '        memberLocation\n'
                        '      }\n'
                        '      updatedAt\n'
                        '      resolvedTime\n'
                        '      resolvedComment\n'
                        '      Symptoms\n'
                        '      MMNodeLinks {\n'
                        '        nextToken\n'
                        '      }\n'
                        '      CheckListInvLink {\n'
                        '        nextToken\n'
                        '      }\n'
                        '      meetingType\n'
                        '      meetingId\n'
                        '    }\n'
                        '  }\n',
 'createinvestigationevent': '\n'
                             '  mutation CreateInvestigationEvent($input: '
                             'CreateInvestigationEventInput!) {\n'
                             '    createInvestigationEvent(input: $input) {\n'
                             '      id\n'
                             '      createdAt\n'
                             '      updatedAt\n'
                             '      author\n'
                             '      content\n'
                             '      type\n'
                             '      links\n'
                             '      investigationId\n'
                             '      investigation {\n'
                             '        id\n'
                             '        title\n'
                             '        from\n'
                             '        createdAt\n'
                             '        currentState\n'
                             '        HumanID\n'
                             '        currentStateID\n'
                             '        severity\n'
                             '        priority\n'
                             '        location\n'
                             '        channelId\n'
                             '        updatedAt\n'
                             '        resolvedTime\n'
                             '        resolvedComment\n'
                             '        Symptoms\n'
                             '        meetingType\n'
                             '        meetingId\n'
                             '      }\n'
                             '    }\n'
                             '  }\n',
 'createinvestigationguestuserlink': '\n'
                                     '  mutation '
                                     'CreateInvestigationGuestUserLink(\n'
                                     '    $input: '
                                     'CreateInvestigationGuestUserLinkInput!\n'
                                     '  ) {\n'
                                     '    '
                                     'createInvestigationGuestUserLink(input: '
                                     '$input) {\n'
                                     '      id\n'
                                     '      userName\n'
                                     '      createdAt\n'
                                     '      updatedAt\n'
                                     '      investigationID\n'
                                     '      channelID\n'
                                     '    }\n'
                                     '  }\n',
 'createlabel': '\n'
                '  mutation CreateLabel($input: CreateLabelInput!) {\n'
                '    createLabel(input: $input) {\n'
                '      id\n'
                '      name\n'
                '      color\n'
                '      type\n'
                '      investigations {\n'
                '        nextToken\n'
                '      }\n'
                '      userSettings {\n'
                '        nextToken\n'
                '      }\n'
                '    }\n'
                '  }\n',
 'createlabellink': '\n'
                    '  mutation CreateLabelLink($input: CreateLabelLinkInput!) '
                    '{\n'
                    '    createLabelLink(input: $input) {\n'
                    '      id\n'
                    '      investigationID\n'
                    '      labelID\n'
                    '      label {\n'
                    '        id\n'
                    '        name\n'
                    '        color\n'
                    '        type\n'
                    '      }\n'
                    '      investigation {\n'
                    '        id\n'
                    '        title\n'
                    '        from\n'
                    '        createdAt\n'
                    '        currentState\n'
                    '        HumanID\n'
                    '        currentStateID\n'
                    '        severity\n'
                    '        priority\n'
                    '        location\n'
                    '        channelId\n'
                    '        updatedAt\n'
                    '        resolvedTime\n'
                    '        resolvedComment\n'
                    '        Symptoms\n'
                    '        meetingType\n'
                    '        meetingId\n'
                    '      }\n'
                    '    }\n'
                    '  }\n',
 'createleadboard': '\n'
                    '  mutation CreateLeadBoard($input: CreateLeadBoardInput!) '
                    '{\n'
                    '    createLeadBoard(input: $input) {\n'
                    '      id\n'
                    '      investigationId\n'
                    '      content\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '      investigation {\n'
                    '        id\n'
                    '        title\n'
                    '        from\n'
                    '        createdAt\n'
                    '        currentState\n'
                    '        HumanID\n'
                    '        currentStateID\n'
                    '        severity\n'
                    '        priority\n'
                    '        location\n'
                    '        channelId\n'
                    '        updatedAt\n'
                    '        resolvedTime\n'
                    '        resolvedComment\n'
                    '        Symptoms\n'
                    '        meetingType\n'
                    '        meetingId\n'
                    '      }\n'
                    '    }\n'
                    '  }\n',
 'createleadboardnode': '\n'
                        '  mutation CreateLeadBoardNode($input: '
                        'CreateLeadBoardNodeInput!) {\n'
                        '    createLeadBoardNode(input: $input) {\n'
                        '      id\n'
                        '      localID\n'
                        '      createdAt\n'
                        '      updatedAt\n'
                        '      author\n'
                        '      content\n'
                        '      title\n'
                        '      notes\n'
                        '      associatedPlaybooks\n'
                        '      associatedCommands\n'
                        '      InvestLinks {\n'
                        '        nextToken\n'
                        '      }\n'
                        '    }\n'
                        '  }\n',
 'createmessage': '\n'
                  '  mutation CreateMessage($input: CreateMessageInput!) {\n'
                  '    createMessage(input: $input) {\n'
                  '      id\n'
                  '      authorId\n'
                  '      content\n'
                  '      type\n'
                  '      channel {\n'
                  '        id\n'
                  '        name\n'
                  '        title\n'
                  '        members\n'
                  '        membersState\n'
                  '        createdAt\n'
                  '        updatedAt\n'
                  '        memberLocation\n'
                  '      }\n'
                  '      messageChannelId\n'
                  '      createdAt\n'
                  '      updatedAt\n'
                  '      author {\n'
                  '        id\n'
                  '        username\n'
                  '        email\n'
                  '        firstname\n'
                  '        lastname\n'
                  '        avatar\n'
                  '        mood\n'
                  '        name\n'
                  '        role\n'
                  '        status\n'
                  '        timezone\n'
                  '        phone\n'
                  '        address\n'
                  '        location\n'
                  '        createdAt\n'
                  '        updatedAt\n'
                  '        owner\n'
                  '      }\n'
                  '    }\n'
                  '  }\n',
 'createmmnodelink': '\n'
                     '  mutation CreateMmNodeLink($input: '
                     'CreateMMNodeLinkInput!) {\n'
                     '    createMMNodeLink(input: $input) {\n'
                     '      id\n'
                     '      createdAt\n'
                     '      updatedAt\n'
                     '      assigned\n'
                     '      state\n'
                     '      content\n'
                     '      author\n'
                     '      investigationID\n'
                     '      connectionToTask\n'
                     '      LBNID\n'
                     '      LeadBoardNodeId {\n'
                     '        id\n'
                     '        localID\n'
                     '        createdAt\n'
                     '        updatedAt\n'
                     '        author\n'
                     '        content\n'
                     '        title\n'
                     '        notes\n'
                     '        associatedPlaybooks\n'
                     '        associatedCommands\n'
                     '      }\n'
                     '      investigationId {\n'
                     '        id\n'
                     '        title\n'
                     '        from\n'
                     '        createdAt\n'
                     '        currentState\n'
                     '        HumanID\n'
                     '        currentStateID\n'
                     '        severity\n'
                     '        priority\n'
                     '        location\n'
                     '        channelId\n'
                     '        updatedAt\n'
                     '        resolvedTime\n'
                     '        resolvedComment\n'
                     '        Symptoms\n'
                     '        meetingType\n'
                     '        meetingId\n'
                     '      }\n'
                     '    }\n'
                     '  }\n',
 'createnotification': '\n'
                       '  mutation CreateNotification($input: '
                       'CreateNotificationInput!) {\n'
                       '    createNotification(input: $input) {\n'
                       '      id\n'
                       '      userName\n'
                       '      content\n'
                       '      containerType\n'
                       '      containerId\n'
                       '      investigationId\n'
                       '      isViewed\n'
                       '      createdAt\n'
                       '      updatedAt\n'
                       '    }\n'
                       '  }\n',
 'createpin': '\n'
              '  mutation CreatePin($input: CreatePinInput!) {\n'
              '    createPin(input: $input) {\n'
              '      id\n'
              '      imageId\n'
              '      content\n'
              '      createdAt\n'
              '      updatedAt\n'
              '      author\n'
              '      investigationId\n'
              '      investigation {\n'
              '        id\n'
              '        title\n'
              '        from\n'
              '        createdAt\n'
              '        currentState\n'
              '        HumanID\n'
              '        currentStateID\n'
              '        severity\n'
              '        priority\n'
              '        location\n'
              '        channelId\n'
              '        updatedAt\n'
              '        resolvedTime\n'
              '        resolvedComment\n'
              '        Symptoms\n'
              '        meetingType\n'
              '        meetingId\n'
              '      }\n'
              '    }\n'
              '  }\n',
 'createprivatekey': '\n'
                     '  mutation CreatePrivateKey($input: '
                     'CreatePrivateKeyInput!) {\n'
                     '    createPrivateKey(input: $input) {\n'
                     '      id\n'
                     '      sshKey\n'
                     '      userName\n'
                     '      createdAt\n'
                     '      updatedAt\n'
                     '    }\n'
                     '  }\n',
 'createremotecontrol': '\n'
                        '  mutation CreateRemoteControl($input: '
                        'CreateRemoteControlInput!) {\n'
                        '    createRemoteControl(input: $input) {\n'
                        '      id\n'
                        '      from\n'
                        '      to\n'
                        '      command\n'
                        '      createdAt\n'
                        '      updatedAt\n'
                        '    }\n'
                        '  }\n',
 'createreportsummaryeditor': '\n'
                              '  mutation CreateReportSummaryEditor($input: '
                              'CreateReportSummaryEditorInput!) {\n'
                              '    createReportSummaryEditor(input: $input) {\n'
                              '      id\n'
                              '      investigationId\n'
                              '      createdAt\n'
                              '      updatedAt\n'
                              '      author\n'
                              '      content\n'
                              '      type\n'
                              '    }\n'
                              '  }\n',
 'createrunbookconnectorformlink': '\n'
                                   '  mutation '
                                   'CreateRunbookConnectorFormLink(\n'
                                   '    $input: '
                                   'CreateRunbookConnectorFormLinkInput!\n'
                                   '  ) {\n'
                                   '    createRunbookConnectorFormLink(input: '
                                   '$input) {\n'
                                   '      id\n'
                                   '      connectorFormId\n'
                                   '      runbookId\n'
                                   '      connectorForm {\n'
                                   '        id\n'
                                   '        createdAt\n'
                                   '        updatedAt\n'
                                   '        name\n'
                                   '        owner\n'
                                   '        connectorID\n'
                                   '        configData\n'
                                   '        commandData\n'
                                   '        nodeData\n'
                                   '        scope\n'
                                   '        PeopleCanView\n'
                                   '        PeopleCanAccess\n'
                                   '        GroupsCanView\n'
                                   '        GroupsCanAccess\n'
                                   '      }\n'
                                   '      runbook {\n'
                                   '        id\n'
                                   '        name\n'
                                   '        description\n'
                                   '        content\n'
                                   '        author\n'
                                   '        commands\n'
                                   '        createdAt\n'
                                   '        updatedAt\n'
                                   '        RunBookConnectors\n'
                                   '        type\n'
                                   '        longSave\n'
                                   '        rbVars\n'
                                   '        scope\n'
                                   '        PeopleCanView\n'
                                   '        PeopleCanAccess\n'
                                   '        GroupsCanView\n'
                                   '        GroupsCanAccess\n'
                                   '      }\n'
                                   '    }\n'
                                   '  }\n',
 'createschedpbs': '\n'
                   '  mutation CreateSchedPBs($input: CreateSchedPBsInput!) {\n'
                   '    createSchedPBs(input: $input) {\n'
                   '      id\n'
                   '      pbId\n'
                   '      frequency\n'
                   '      pbName\n'
                   '      rbVars\n'
                   '      scheduled\n'
                   '      createdAt\n'
                   '      updatedAt\n'
                   '      author\n'
                   '    }\n'
                   '  }\n',
 'createslackchannelinfo': '\n'
                           '  mutation CreateSlackChannelInfo($input: '
                           'CreateSlackChannelInfoInput!) {\n'
                           '    createSlackChannelInfo(input: $input) {\n'
                           '      id\n'
                           '      owner\n'
                           '      slackChannelId\n'
                           '      slackAppId\n'
                           '      slackTeamId\n'
                           '      slackTeam {\n'
                           '        id\n'
                           '        owner\n'
                           '        teamId\n'
                           '        teamName\n'
                           '        slackAppId\n'
                           '        botId\n'
                           '        botToken\n'
                           '        botScope\n'
                           '        enterprise\n'
                           '      }\n'
                           '      usersEnabled {\n'
                           '        nextToken\n'
                           '      }\n'
                           '    }\n'
                           '  }\n',
 'createslackenabledchannelsuserlink': '\n'
                                       '  mutation '
                                       'CreateSlackEnabledChannelsUserLink(\n'
                                       '    $input: '
                                       'CreateSlackEnabledChannelsUserLinkInput!\n'
                                       '  ) {\n'
                                       '    '
                                       'createSlackEnabledChannelsUserLink(input: '
                                       '$input) {\n'
                                       '      id\n'
                                       '      owner\n'
                                       '      slackUserId\n'
                                       '      slackChannelId\n'
                                       '      slackUser {\n'
                                       '        id\n'
                                       '        userAppSyncId\n'
                                       '        userName\n'
                                       '        userId\n'
                                       '        userScope\n'
                                       '        userToken\n'
                                       '        slackAppId\n'
                                       '        slackTeamId\n'
                                       '      }\n'
                                       '      slackChannel {\n'
                                       '        id\n'
                                       '        owner\n'
                                       '        slackChannelId\n'
                                       '        slackAppId\n'
                                       '        slackTeamId\n'
                                       '      }\n'
                                       '    }\n'
                                       '  }\n',
 'createslackteaminfo': '\n'
                        '  mutation CreateSlackTeamInfo($input: '
                        'CreateSlackTeamInfoInput!) {\n'
                        '    createSlackTeamInfo(input: $input) {\n'
                        '      id\n'
                        '      owner\n'
                        '      teamId\n'
                        '      teamName\n'
                        '      slackAppId\n'
                        '      botId\n'
                        '      botToken\n'
                        '      botScope\n'
                        '      enterprise\n'
                        '    }\n'
                        '  }\n',
 'createslackuserinfo': '\n'
                        '  mutation CreateSlackUserInfo($input: '
                        'CreateSlackUserInfoInput!) {\n'
                        '    createSlackUserInfo(input: $input) {\n'
                        '      id\n'
                        '      userAppSyncId\n'
                        '      userName\n'
                        '      userId\n'
                        '      userScope\n'
                        '      userToken\n'
                        '      slackAppId\n'
                        '      slackTeamId\n'
                        '      userGqlInfo {\n'
                        '        id\n'
                        '        username\n'
                        '        email\n'
                        '        firstname\n'
                        '        lastname\n'
                        '        avatar\n'
                        '        mood\n'
                        '        name\n'
                        '        role\n'
                        '        status\n'
                        '        timezone\n'
                        '        phone\n'
                        '        address\n'
                        '        location\n'
                        '        createdAt\n'
                        '        updatedAt\n'
                        '        owner\n'
                        '      }\n'
                        '      slackTeam {\n'
                        '        id\n'
                        '        owner\n'
                        '        teamId\n'
                        '        teamName\n'
                        '        slackAppId\n'
                        '        botId\n'
                        '        botToken\n'
                        '        botScope\n'
                        '        enterprise\n'
                        '      }\n'
                        '      channelsEnabled {\n'
                        '        nextToken\n'
                        '      }\n'
                        '    }\n'
                        '  }\n',
 'createsshtabs': '\n'
                  '  mutation CreateSshTabs($input: CreateSshTabsInput!) {\n'
                  '    createSshTabs(input: $input) {\n'
                  '      id\n'
                  '      investigationId\n'
                  '      host\n'
                  '      author\n'
                  '      userName\n'
                  '      createdAt\n'
                  '      updatedAt\n'
                  '    }\n'
                  '  }\n',
 'createstash': '\n'
                '  mutation CreateStash($input: CreateStashInput!) {\n'
                '    createStash(input: $input) {\n'
                '      id\n'
                '      Key\n'
                '      Value\n'
                '      createdAt\n'
                '      updatedAt\n'
                '      author\n'
                '      scope\n'
                '      PeopleCanView\n'
                '      PeopleCanAccess\n'
                '      GroupsCanView\n'
                '      GroupsCanAccess\n'
                '    }\n'
                '  }\n',
 'createstate': '\n'
                '  mutation CreateState($input: CreateStateInput!) {\n'
                '    createState(input: $input) {\n'
                '      id\n'
                '      name\n'
                '      createdAt\n'
                '      updatedAt\n'
                '      author\n'
                '      lastState\n'
                '      investigationId\n'
                '      investigation {\n'
                '        id\n'
                '        title\n'
                '        from\n'
                '        createdAt\n'
                '        currentState\n'
                '        HumanID\n'
                '        currentStateID\n'
                '        severity\n'
                '        priority\n'
                '        location\n'
                '        channelId\n'
                '        updatedAt\n'
                '        resolvedTime\n'
                '        resolvedComment\n'
                '        Symptoms\n'
                '        meetingType\n'
                '        meetingId\n'
                '      }\n'
                '    }\n'
                '  }\n',
 'createsummaryinvestigation': '\n'
                               '  mutation CreateSummaryInvestigation(\n'
                               '    $input: CreateSummaryInvestigationInput!\n'
                               '  ) {\n'
                               '    createSummaryInvestigation(input: $input) '
                               '{\n'
                               '      id\n'
                               '      createdAt\n'
                               '      updatedAt\n'
                               '      resolvedTime\n'
                               '      OriginalID\n'
                               '      title\n'
                               '      HumanID\n'
                               '      Commands\n'
                               '      InvestigationEvents\n'
                               '      CompleteInvestigationEvents\n'
                               '      Participants\n'
                               '      Comments\n'
                               '      Pins\n'
                               '      AvailableRunbooks\n'
                               '      UsedRunbooks\n'
                               '      Hints\n'
                               '      Symptoms\n'
                               '      owner\n'
                               '    }\n'
                               '  }\n',
 'createtenantcustomer': '\n'
                         '  mutation CreateTenantCustomer($input: '
                         'CreateTenantCustomerInput!) {\n'
                         '    createTenantCustomer(input: $input) {\n'
                         '      label\n'
                         '      impactLabels\n'
                         '      createdAt\n'
                         '      updatedAt\n'
                         '      customerName\n'
                         '      email\n'
                         '      phoneno\n'
                         '      SLAType\n'
                         '      city\n'
                         '      state\n'
                         '      contry\n'
                         '      zipcode\n'
                         '    }\n'
                         '  }\n',
 'createtranscriptionrecords': '\n'
                               '  mutation CreateTranscriptionRecords(\n'
                               '    $input: CreateTranscriptionRecordsInput!\n'
                               '  ) {\n'
                               '    createTranscriptionRecords(input: $input) '
                               '{\n'
                               '      id\n'
                               '      investigationId\n'
                               '      createdAt\n'
                               '      updatedAt\n'
                               '      spokenBy\n'
                               '      content\n'
                               '    }\n'
                               '  }\n',
 'createusedtogenhintalready': '\n'
                               '  mutation CreateUsedToGenHintAlready(\n'
                               '    $input: CreateUsedToGenHintAlreadyInput!\n'
                               '  ) {\n'
                               '    createUsedToGenHintAlready(input: $input) '
                               '{\n'
                               '      id\n'
                               '      createdAt\n'
                               '      updatedAt\n'
                               '      investigationId\n'
                               '      commands\n'
                               '      text\n'
                               '      investigation {\n'
                               '        id\n'
                               '        title\n'
                               '        from\n'
                               '        createdAt\n'
                               '        currentState\n'
                               '        HumanID\n'
                               '        currentStateID\n'
                               '        severity\n'
                               '        priority\n'
                               '        location\n'
                               '        channelId\n'
                               '        updatedAt\n'
                               '        resolvedTime\n'
                               '        resolvedComment\n'
                               '        Symptoms\n'
                               '        meetingType\n'
                               '        meetingId\n'
                               '      }\n'
                               '    }\n'
                               '  }\n',
 'createuser': '\n'
               '  mutation CreateUser($input: CreateUserInput!) {\n'
               '    createUser(input: $input) {\n'
               '      id\n'
               '      username\n'
               '      email\n'
               '      firstname\n'
               '      lastname\n'
               '      avatar\n'
               '      mood\n'
               '      name\n'
               '      role\n'
               '      status\n'
               '      timezone\n'
               '      phone\n'
               '      address\n'
               '      location\n'
               '      chatList {\n'
               '        nextToken\n'
               '      }\n'
               '      messages {\n'
               '        nextToken\n'
               '      }\n'
               '      createdAt\n'
               '      updatedAt\n'
               '      owner\n'
               '    }\n'
               '  }\n',
 'createuseractivity': '\n'
                       '  mutation CreateUserActivity($input: '
                       'CreateUserActivityInput!) {\n'
                       '    createUserActivity(input: $input) {\n'
                       '      id\n'
                       '      userID\n'
                       '      status\n'
                       '      investigationID\n'
                       '      createdAt\n'
                       '      updatedAt\n'
                       '      investigation {\n'
                       '        id\n'
                       '        title\n'
                       '        from\n'
                       '        createdAt\n'
                       '        currentState\n'
                       '        HumanID\n'
                       '        currentStateID\n'
                       '        severity\n'
                       '        priority\n'
                       '        location\n'
                       '        channelId\n'
                       '        updatedAt\n'
                       '        resolvedTime\n'
                       '        resolvedComment\n'
                       '        Symptoms\n'
                       '        meetingType\n'
                       '        meetingId\n'
                       '      }\n'
                       '      user {\n'
                       '        id\n'
                       '        username\n'
                       '        email\n'
                       '        firstname\n'
                       '        lastname\n'
                       '        avatar\n'
                       '        mood\n'
                       '        name\n'
                       '        role\n'
                       '        status\n'
                       '        timezone\n'
                       '        phone\n'
                       '        address\n'
                       '        location\n'
                       '        createdAt\n'
                       '        updatedAt\n'
                       '        owner\n'
                       '      }\n'
                       '    }\n'
                       '  }\n',
 'createusersetting': '\n'
                      '  mutation CreateUserSetting($input: '
                      'CreateUserSettingInput!) {\n'
                      '    createUserSetting(input: $input) {\n'
                      '      id\n'
                      '      userId\n'
                      '      owner\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '      labels {\n'
                      '        nextToken\n'
                      '      }\n'
                      '      value\n'
                      '      url\n'
                      '      name\n'
                      '      type\n'
                      '      showWelcomeNext\n'
                      '      showWelcomeSkip\n'
                      '      showWelcomeRemind\n'
                      '      welcomeData\n'
                      '    }\n'
                      '  }\n',
 'createusersettinglabellink': '\n'
                               '  mutation CreateUserSettingLabelLink(\n'
                               '    $input: CreateUserSettingLabelLinkInput!\n'
                               '  ) {\n'
                               '    createUserSettingLabelLink(input: $input) '
                               '{\n'
                               '      id\n'
                               '      userSettingId\n'
                               '      userSetting {\n'
                               '        id\n'
                               '        userId\n'
                               '        owner\n'
                               '        createdAt\n'
                               '        updatedAt\n'
                               '        value\n'
                               '        url\n'
                               '        name\n'
                               '        type\n'
                               '        showWelcomeNext\n'
                               '        showWelcomeSkip\n'
                               '        showWelcomeRemind\n'
                               '        welcomeData\n'
                               '      }\n'
                               '      labelID\n'
                               '      label {\n'
                               '        id\n'
                               '        name\n'
                               '        color\n'
                               '        type\n'
                               '      }\n'
                               '      type\n'
                               '    }\n'
                               '  }\n',
 'deletealertapikey': '\n'
                      '  mutation DeleteAlertApiKey($input: '
                      'DeleteAlertApiKeyInput!) {\n'
                      '    deleteAlertApiKey(input: $input) {\n'
                      '      id\n'
                      '      alertsPbName\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '      author\n'
                      '    }\n'
                      '  }\n',
 'deleteallrunbooks': '\n'
                      '  mutation DeleteAllRunbooks($input: '
                      'DeleteAllRunbooksInput!) {\n'
                      '    deleteAllRunbooks(input: $input) {\n'
                      '      id\n'
                      '      name\n'
                      '      description\n'
                      '      content\n'
                      '      author\n'
                      '      commands\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '      RunBookConnectors\n'
                      '      type\n'
                      '      longSave\n'
                      '      rbVars\n'
                      '      scope\n'
                      '      PeopleCanView\n'
                      '      PeopleCanAccess\n'
                      '      GroupsCanView\n'
                      '      GroupsCanAccess\n'
                      '      connectorForms {\n'
                      '        nextToken\n'
                      '      }\n'
                      '    }\n'
                      '  }\n',
 'deleteallworkflows': '\n'
                       '  mutation DeleteAllWorkflows($input: '
                       'DeleteAllWorkflowsInput!) {\n'
                       '    deleteAllWorkflows(input: $input) {\n'
                       '      id\n'
                       '      createdAt\n'
                       '      updatedAt\n'
                       '      name\n'
                       '      description\n'
                       '      type\n'
                       '      author\n'
                       '      longSave\n'
                       '      rbVars\n'
                       '    }\n'
                       '  }\n',
 'deletebase64image': '\n'
                      '  mutation DeleteBase64Image($input: '
                      'DeleteBase64ImageInput!) {\n'
                      '    deleteBase64Image(input: $input) {\n'
                      '      id\n'
                      '      playbookID\n'
                      '      base64String\n'
                      '    }\n'
                      '  }\n',
 'deletechannel': '\n'
                  '  mutation DeleteChannel($input: DeleteChannelInput!) {\n'
                  '    deleteChannel(input: $input) {\n'
                  '      id\n'
                  '      messages {\n'
                  '        nextToken\n'
                  '      }\n'
                  '      associated {\n'
                  '        nextToken\n'
                  '      }\n'
                  '      name\n'
                  '      title\n'
                  '      members\n'
                  '      membersState\n'
                  '      createdAt\n'
                  '      updatedAt\n'
                  '      memberLocation\n'
                  '    }\n'
                  '  }\n',
 'deletechannellink': '\n'
                      '  mutation DeleteChannelLink($input: '
                      'DeleteChannelLinkInput!) {\n'
                      '    deleteChannelLink(input: $input) {\n'
                      '      id\n'
                      '      contactId\n'
                      '      channel {\n'
                      '        id\n'
                      '        name\n'
                      '        title\n'
                      '        members\n'
                      '        membersState\n'
                      '        createdAt\n'
                      '        updatedAt\n'
                      '        memberLocation\n'
                      '      }\n'
                      '      chatId\n'
                      '      unread\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '      user {\n'
                      '        id\n'
                      '        username\n'
                      '        email\n'
                      '        firstname\n'
                      '        lastname\n'
                      '        avatar\n'
                      '        mood\n'
                      '        name\n'
                      '        role\n'
                      '        status\n'
                      '        timezone\n'
                      '        phone\n'
                      '        address\n'
                      '        location\n'
                      '        createdAt\n'
                      '        updatedAt\n'
                      '        owner\n'
                      '      }\n'
                      '    }\n'
                      '  }\n',
 'deletechat': '\n'
               '  mutation DeleteChat($input: DeleteChatInput!) {\n'
               '    deleteChat(input: $input) {\n'
               '      id\n'
               '      from\n'
               '      content\n'
               '      createdAt\n'
               '    }\n'
               '  }\n',
 'deletecheatsheet': '\n'
                     '  mutation DeleteCheatSheet($input: '
                     'DeleteCheatSheetInput!) {\n'
                     '    deleteCheatSheet(input: $input) {\n'
                     '      id\n'
                     '      createdAt\n'
                     '      updatedAt\n'
                     '      title\n'
                     '      author\n'
                     '      content\n'
                     '      type\n'
                     '    }\n'
                     '  }\n',
 'deletechecklist': '\n'
                    '  mutation DeleteCheckList($input: DeleteCheckListInput!) '
                    '{\n'
                    '    deleteCheckList(input: $input) {\n'
                    '      id\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '      name\n'
                    '      description\n'
                    '      type\n'
                    '      content\n'
                    '      author\n'
                    '      CheckListLink {\n'
                    '        nextToken\n'
                    '      }\n'
                    '      CheckListInvLink {\n'
                    '        nextToken\n'
                    '      }\n'
                    '    }\n'
                    '  }\n',
 'deletechecklistinvlink': '\n'
                           '  mutation DeleteCheckListInvLink($input: '
                           'DeleteCheckListInvLinkInput!) {\n'
                           '    deleteCheckListInvLink(input: $input) {\n'
                           '      id\n'
                           '      createdAt\n'
                           '      updatedAt\n'
                           '      investigationID\n'
                           '      CheckListID\n'
                           '      CheckList {\n'
                           '        id\n'
                           '        createdAt\n'
                           '        updatedAt\n'
                           '        name\n'
                           '        description\n'
                           '        type\n'
                           '        content\n'
                           '        author\n'
                           '      }\n'
                           '      investigation {\n'
                           '        id\n'
                           '        title\n'
                           '        from\n'
                           '        createdAt\n'
                           '        currentState\n'
                           '        HumanID\n'
                           '        currentStateID\n'
                           '        severity\n'
                           '        priority\n'
                           '        location\n'
                           '        channelId\n'
                           '        updatedAt\n'
                           '        resolvedTime\n'
                           '        resolvedComment\n'
                           '        Symptoms\n'
                           '        meetingType\n'
                           '        meetingId\n'
                           '      }\n'
                           '      owner\n'
                           '    }\n'
                           '  }\n',
 'deletechecklistitem': '\n'
                        '  mutation DeleteCheckListItem($input: '
                        'DeleteCheckListItemInput!) {\n'
                        '    deleteCheckListItem(input: $input) {\n'
                        '      id\n'
                        '      localID\n'
                        '      createdAt\n'
                        '      updatedAt\n'
                        '      author\n'
                        '      content\n'
                        '      title\n'
                        '      type\n'
                        '      connection\n'
                        '      MMNodeConnection\n'
                        '      investigationID\n'
                        '      assignee\n'
                        '      associatedPlaybooks\n'
                        '      associatedCommands\n'
                        '      CheckListLink {\n'
                        '        nextToken\n'
                        '      }\n'
                        '    }\n'
                        '  }\n',
 'deleteclick': '\n'
                '  mutation DeleteClick($input: DeleteClickInput!) {\n'
                '    deleteClick(input: $input) {\n'
                '      id\n'
                '      count\n'
                '      type\n'
                '      featureName\n'
                '      createdAt\n'
                '      updatedAt\n'
                '      readAt\n'
                '    }\n'
                '  }\n',
 'deleteclicllink': '\n'
                    '  mutation DeleteCliclLink($input: DeleteCLICLLinkInput!) '
                    '{\n'
                    '    deleteCLICLLink(input: $input) {\n'
                    '      id\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '      CheckListItemID\n'
                    '      lane\n'
                    '      CheckListID\n'
                    '      CheckList {\n'
                    '        id\n'
                    '        createdAt\n'
                    '        updatedAt\n'
                    '        name\n'
                    '        description\n'
                    '        type\n'
                    '        content\n'
                    '        author\n'
                    '      }\n'
                    '      CheckListItem {\n'
                    '        id\n'
                    '        localID\n'
                    '        createdAt\n'
                    '        updatedAt\n'
                    '        author\n'
                    '        content\n'
                    '        title\n'
                    '        type\n'
                    '        connection\n'
                    '        MMNodeConnection\n'
                    '        investigationID\n'
                    '        assignee\n'
                    '        associatedPlaybooks\n'
                    '        associatedCommands\n'
                    '      }\n'
                    '    }\n'
                    '  }\n',
 'deletecommands': '\n'
                   '  mutation DeleteCommands($input: DeleteCommandsInput!) {\n'
                   '    deleteCommands(input: $input) {\n'
                   '      id\n'
                   '      from\n'
                   '      mode\n'
                   '      command\n'
                   '      output\n'
                   '      state\n'
                   '      returnCode\n'
                   '      investigationId\n'
                   '      createdAt\n'
                   '      updatedAt\n'
                   '      investigation {\n'
                   '        id\n'
                   '        title\n'
                   '        from\n'
                   '        createdAt\n'
                   '        currentState\n'
                   '        HumanID\n'
                   '        currentStateID\n'
                   '        severity\n'
                   '        priority\n'
                   '        location\n'
                   '        channelId\n'
                   '        updatedAt\n'
                   '        resolvedTime\n'
                   '        resolvedComment\n'
                   '        Symptoms\n'
                   '        meetingType\n'
                   '        meetingId\n'
                   '      }\n'
                   '    }\n'
                   '  }\n',
 'deletecomment': '\n'
                  '  mutation DeleteComment($input: DeleteCommentInput!) {\n'
                  '    deleteComment(input: $input) {\n'
                  '      id\n'
                  '      parent\n'
                  '      createdAt\n'
                  '      updatedAt\n'
                  '      author\n'
                  '      content\n'
                  '      type\n'
                  '      links\n'
                  '      investigationId\n'
                  '      investigation {\n'
                  '        id\n'
                  '        title\n'
                  '        from\n'
                  '        createdAt\n'
                  '        currentState\n'
                  '        HumanID\n'
                  '        currentStateID\n'
                  '        severity\n'
                  '        priority\n'
                  '        location\n'
                  '        channelId\n'
                  '        updatedAt\n'
                  '        resolvedTime\n'
                  '        resolvedComment\n'
                  '        Symptoms\n'
                  '        meetingType\n'
                  '        meetingId\n'
                  '      }\n'
                  '    }\n'
                  '  }\n',
 'deleteconferenceconfig': '\n'
                           '  mutation DeleteConferenceConfig($input: '
                           'DeleteConferenceConfigInput!) {\n'
                           '    deleteConferenceConfig(input: $input) {\n'
                           '      id\n'
                           '      url\n'
                           '      userName\n'
                           '      password\n'
                           '      author\n'
                           '      createdAt\n'
                           '      updatedAt\n'
                           '    }\n'
                           '  }\n',
 'deleteconnectorform': '\n'
                        '  mutation DeleteConnectorForm($input: '
                        'DeleteConnectorFormInput!) {\n'
                        '    deleteConnectorForm(input: $input) {\n'
                        '      id\n'
                        '      createdAt\n'
                        '      updatedAt\n'
                        '      name\n'
                        '      owner\n'
                        '      connectorID\n'
                        '      connector {\n'
                        '        id\n'
                        '        createdAt\n'
                        '        updatedAt\n'
                        '        category\n'
                        '        name\n'
                        '        owner\n'
                        '        description\n'
                        '        detaileddescription\n'
                        '        iconPath\n'
                        '        version\n'
                        '        md5\n'
                        '        source\n'
                        '        configuration\n'
                        '        commands\n'
                        '        commandsType\n'
                        '        script\n'
                        '        scriptType\n'
                        '        scriptPath\n'
                        '        scope\n'
                        '        PeopleCanView\n'
                        '        PeopleCanAccess\n'
                        '        GroupsCanView\n'
                        '        GroupsCanAccess\n'
                        '      }\n'
                        '      configData\n'
                        '      commandData\n'
                        '      nodeData\n'
                        '      scope\n'
                        '      PeopleCanView\n'
                        '      PeopleCanAccess\n'
                        '      GroupsCanView\n'
                        '      GroupsCanAccess\n'
                        '      runbooks {\n'
                        '        nextToken\n'
                        '      }\n'
                        '    }\n'
                        '  }\n',
 'deleteconnectors': '\n'
                     '  mutation DeleteConnectors($input: '
                     'DeleteConnectorsInput!) {\n'
                     '    deleteConnectors(input: $input) {\n'
                     '      id\n'
                     '      createdAt\n'
                     '      updatedAt\n'
                     '      category\n'
                     '      name\n'
                     '      owner\n'
                     '      description\n'
                     '      detaileddescription\n'
                     '      iconPath\n'
                     '      version\n'
                     '      md5\n'
                     '      source\n'
                     '      configuration\n'
                     '      commands\n'
                     '      commandsType\n'
                     '      script\n'
                     '      scriptType\n'
                     '      scriptPath\n'
                     '      scope\n'
                     '      PeopleCanView\n'
                     '      PeopleCanAccess\n'
                     '      GroupsCanView\n'
                     '      GroupsCanAccess\n'
                     '    }\n'
                     '  }\n',
 'deletedashboardconfig': '\n'
                          '  mutation DeleteDashboardConfig($input: '
                          'DeleteDashboardConfigInput!) {\n'
                          '    deleteDashboardConfig(input: $input) {\n'
                          '      id\n'
                          '      url\n'
                          '      labels {\n'
                          '        nextToken\n'
                          '      }\n'
                          '      author\n'
                          '      createdAt\n'
                          '      updatedAt\n'
                          '    }\n'
                          '  }\n',
 'deletedashboardconfiglabellink': '\n'
                                   '  mutation '
                                   'DeleteDashboardConfigLabelLink(\n'
                                   '    $input: '
                                   'DeleteDashboardConfigLabelLinkInput!\n'
                                   '  ) {\n'
                                   '    deleteDashboardConfigLabelLink(input: '
                                   '$input) {\n'
                                   '      id\n'
                                   '      dashboardConfigID\n'
                                   '      labelID\n'
                                   '      dashboardConfig {\n'
                                   '        id\n'
                                   '        url\n'
                                   '        author\n'
                                   '        createdAt\n'
                                   '        updatedAt\n'
                                   '      }\n'
                                   '      label {\n'
                                   '        id\n'
                                   '        name\n'
                                   '        color\n'
                                   '        type\n'
                                   '      }\n'
                                   '    }\n'
                                   '  }\n',
 'deleteecubesandboxexecution': '\n'
                                '  mutation DeleteEcubeSandboxExecution(\n'
                                '    $input: '
                                'DeleteEcubeSandboxExecutionInput!\n'
                                '  ) {\n'
                                '    deleteEcubeSandboxExecution(input: '
                                '$input) {\n'
                                '      id\n'
                                '      owner\n'
                                '      output\n'
                                '      outputType\n'
                                '      returnCode\n'
                                '      status\n'
                                '      createdAt\n'
                                '      updatedAt\n'
                                '      E3One\n'
                                '      E3Two\n'
                                '      E3Three\n'
                                '    }\n'
                                '  }\n',
 'deleteepicautocomplete': '\n'
                           '  mutation DeleteEpicAutoComplete($input: '
                           'DeleteEpicAutoCompleteInput!) {\n'
                           '    deleteEpicAutoComplete(input: $input) {\n'
                           '      id\n'
                           '      author\n'
                           '      cliCommand\n'
                           '      command\n'
                           '      createdAt\n'
                           '      updatedAt\n'
                           '      investigationId\n'
                           '      times\n'
                           '    }\n'
                           '  }\n',
 'deleteepiclicommand': '\n'
                        '  mutation DeleteEpicliCommand($input: '
                        'DeleteEPICLICommandInput!) {\n'
                        '    deleteEPICLICommand(input: $input) {\n'
                        '      id\n'
                        '      createdAt\n'
                        '      updatedAt\n'
                        '      author\n'
                        '      content\n'
                        '      type\n'
                        '    }\n'
                        '  }\n',
 'deleteexecutedrunbooks': '\n'
                           '  mutation DeleteExecutedRunbooks($input: '
                           'DeleteExecutedRunbooksInput!) {\n'
                           '    deleteExecutedRunbooks(input: $input) {\n'
                           '      id\n'
                           '      createdAt\n'
                           '      updatedAt\n'
                           '      runbookID\n'
                           '      investigationId\n'
                           '      output\n'
                           '      outputType\n'
                           '      title\n'
                           '      state\n'
                           '      author\n'
                           '      rbVars\n'
                           '      callbackUrl\n'
                           '      callbackData\n'
                           '      source\n'
                           '      investigation {\n'
                           '        id\n'
                           '        title\n'
                           '        from\n'
                           '        createdAt\n'
                           '        currentState\n'
                           '        HumanID\n'
                           '        currentStateID\n'
                           '        severity\n'
                           '        priority\n'
                           '        location\n'
                           '        channelId\n'
                           '        updatedAt\n'
                           '        resolvedTime\n'
                           '        resolvedComment\n'
                           '        Symptoms\n'
                           '        meetingType\n'
                           '        meetingId\n'
                           '      }\n'
                           '      runbook {\n'
                           '        id\n'
                           '        name\n'
                           '        description\n'
                           '        content\n'
                           '        author\n'
                           '        commands\n'
                           '        createdAt\n'
                           '        updatedAt\n'
                           '        RunBookConnectors\n'
                           '        type\n'
                           '        longSave\n'
                           '        rbVars\n'
                           '        scope\n'
                           '        PeopleCanView\n'
                           '        PeopleCanAccess\n'
                           '        GroupsCanView\n'
                           '        GroupsCanAccess\n'
                           '      }\n'
                           '    }\n'
                           '  }\n',
 'deleteexecutedworkflowstate': '\n'
                                '  mutation DeleteExecutedWorkflowState(\n'
                                '    $input: '
                                'DeleteExecutedWorkflowStateInput!\n'
                                '  ) {\n'
                                '    deleteExecutedWorkflowState(input: '
                                '$input) {\n'
                                '      id\n'
                                '      createdAt\n'
                                '      updatedAt\n'
                                '      name\n'
                                '      state\n'
                                '      output\n'
                                '      type\n'
                                '      allworkflowID\n'
                                '      investigationID\n'
                                '      investigation {\n'
                                '        id\n'
                                '        title\n'
                                '        from\n'
                                '        createdAt\n'
                                '        currentState\n'
                                '        HumanID\n'
                                '        currentStateID\n'
                                '        severity\n'
                                '        priority\n'
                                '        location\n'
                                '        channelId\n'
                                '        updatedAt\n'
                                '        resolvedTime\n'
                                '        resolvedComment\n'
                                '        Symptoms\n'
                                '        meetingType\n'
                                '        meetingId\n'
                                '      }\n'
                                '    }\n'
                                '  }\n',
 'deletegroupmember': '\n'
                      '  mutation DeleteGroupMember($input: '
                      'DeleteGroupMemberInput!) {\n'
                      '    deleteGroupMember(input: $input) {\n'
                      '      id\n'
                      '      hostId\n'
                      '      groupId\n'
                      '      host {\n'
                      '        id\n'
                      '        inventoryId\n'
                      '        createdAt\n'
                      '        updatedAt\n'
                      '        author\n'
                      '        host\n'
                      '        port\n'
                      '        vars\n'
                      '      }\n'
                      '      group {\n'
                      '        id\n'
                      '        inventoryId\n'
                      '        createdAt\n'
                      '        updatedAt\n'
                      '        author\n'
                      '        name\n'
                      '        groups\n'
                      '        port\n'
                      '        vars\n'
                      '      }\n'
                      '    }\n'
                      '  }\n',
 'deleteguardrail': '\n'
                    '  mutation DeleteGuardRail($input: DeleteGuardRailInput!) '
                    '{\n'
                    '    deleteGuardRail(input: $input) {\n'
                    '      id\n'
                    '      timeOut\n'
                    '      message\n'
                    '      labels {\n'
                    '        nextToken\n'
                    '      }\n'
                    '      author\n'
                    '      active\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '    }\n'
                    '  }\n',
 'deleteguardraillabellink': '\n'
                             '  mutation DeleteGuardRailLabelLink($input: '
                             'DeleteGuardRailLabelLinkInput!) {\n'
                             '    deleteGuardRailLabelLink(input: $input) {\n'
                             '      id\n'
                             '      guardRailID\n'
                             '      labelID\n'
                             '      guardRail {\n'
                             '        id\n'
                             '        timeOut\n'
                             '        message\n'
                             '        author\n'
                             '        active\n'
                             '        createdAt\n'
                             '        updatedAt\n'
                             '      }\n'
                             '      label {\n'
                             '        id\n'
                             '        name\n'
                             '        color\n'
                             '        type\n'
                             '      }\n'
                             '    }\n'
                             '  }\n',
 'deletehint': '\n'
               '  mutation DeleteHint($input: DeleteHintInput!) {\n'
               '    deleteHint(input: $input) {\n'
               '      id\n'
               '      investigationId\n'
               '      createdAt\n'
               '      updatedAt\n'
               '      type\n'
               '      connection\n'
               '      pastInvestigationID\n'
               '      title\n'
               '      importance\n'
               '      starrted\n'
               '      applied\n'
               '      url\n'
               '      why\n'
               '    }\n'
               '  }\n',
 'deleteinventory': '\n'
                    '  mutation DeleteInventory($input: DeleteInventoryInput!) '
                    '{\n'
                    '    deleteInventory(input: $input) {\n'
                    '      id\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '      author\n'
                    '      name\n'
                    '      all {\n'
                    '        nextToken\n'
                    '      }\n'
                    '      groups {\n'
                    '        nextToken\n'
                    '      }\n'
                    '      vars\n'
                    '    }\n'
                    '  }\n',
 'deleteinventorygroup': '\n'
                         '  mutation DeleteInventoryGroup($input: '
                         'DeleteInventoryGroupInput!) {\n'
                         '    deleteInventoryGroup(input: $input) {\n'
                         '      id\n'
                         '      inventoryId\n'
                         '      createdAt\n'
                         '      updatedAt\n'
                         '      author\n'
                         '      name\n'
                         '      hosts {\n'
                         '        nextToken\n'
                         '      }\n'
                         '      groups\n'
                         '      port\n'
                         '      vars\n'
                         '      inventory {\n'
                         '        id\n'
                         '        createdAt\n'
                         '        updatedAt\n'
                         '        author\n'
                         '        name\n'
                         '        vars\n'
                         '      }\n'
                         '    }\n'
                         '  }\n',
 'deleteinventoryhost': '\n'
                        '  mutation DeleteInventoryHost($input: '
                        'DeleteInventoryHostInput!) {\n'
                        '    deleteInventoryHost(input: $input) {\n'
                        '      id\n'
                        '      inventoryId\n'
                        '      createdAt\n'
                        '      updatedAt\n'
                        '      author\n'
                        '      host\n'
                        '      port\n'
                        '      vars\n'
                        '      groups {\n'
                        '        nextToken\n'
                        '      }\n'
                        '      inventory {\n'
                        '        id\n'
                        '        createdAt\n'
                        '        updatedAt\n'
                        '        author\n'
                        '        name\n'
                        '        vars\n'
                        '      }\n'
                        '    }\n'
                        '  }\n',
 'deleteinvestigation': '\n'
                        '  mutation DeleteInvestigation($input: '
                        'DeleteInvestigationInput!) {\n'
                        '    deleteInvestigation(input: $input) {\n'
                        '      id\n'
                        '      title\n'
                        '      from\n'
                        '      createdAt\n'
                        '      currentState\n'
                        '      HumanID\n'
                        '      currentStateID\n'
                        '      severity\n'
                        '      priority\n'
                        '      location\n'
                        '      labels {\n'
                        '        nextToken\n'
                        '      }\n'
                        '      channelId\n'
                        '      investigationChannel {\n'
                        '        id\n'
                        '        name\n'
                        '        title\n'
                        '        members\n'
                        '        membersState\n'
                        '        createdAt\n'
                        '        updatedAt\n'
                        '        memberLocation\n'
                        '      }\n'
                        '      updatedAt\n'
                        '      resolvedTime\n'
                        '      resolvedComment\n'
                        '      Symptoms\n'
                        '      MMNodeLinks {\n'
                        '        nextToken\n'
                        '      }\n'
                        '      CheckListInvLink {\n'
                        '        nextToken\n'
                        '      }\n'
                        '      meetingType\n'
                        '      meetingId\n'
                        '    }\n'
                        '  }\n',
 'deleteinvestigationevent': '\n'
                             '  mutation DeleteInvestigationEvent($input: '
                             'DeleteInvestigationEventInput!) {\n'
                             '    deleteInvestigationEvent(input: $input) {\n'
                             '      id\n'
                             '      createdAt\n'
                             '      updatedAt\n'
                             '      author\n'
                             '      content\n'
                             '      type\n'
                             '      links\n'
                             '      investigationId\n'
                             '      investigation {\n'
                             '        id\n'
                             '        title\n'
                             '        from\n'
                             '        createdAt\n'
                             '        currentState\n'
                             '        HumanID\n'
                             '        currentStateID\n'
                             '        severity\n'
                             '        priority\n'
                             '        location\n'
                             '        channelId\n'
                             '        updatedAt\n'
                             '        resolvedTime\n'
                             '        resolvedComment\n'
                             '        Symptoms\n'
                             '        meetingType\n'
                             '        meetingId\n'
                             '      }\n'
                             '    }\n'
                             '  }\n',
 'deleteinvestigationguestuserlink': '\n'
                                     '  mutation '
                                     'DeleteInvestigationGuestUserLink(\n'
                                     '    $input: '
                                     'DeleteInvestigationGuestUserLinkInput!\n'
                                     '  ) {\n'
                                     '    '
                                     'deleteInvestigationGuestUserLink(input: '
                                     '$input) {\n'
                                     '      id\n'
                                     '      userName\n'
                                     '      createdAt\n'
                                     '      updatedAt\n'
                                     '      investigationID\n'
                                     '      channelID\n'
                                     '    }\n'
                                     '  }\n',
 'deletelabel': '\n'
                '  mutation DeleteLabel($input: DeleteLabelInput!) {\n'
                '    deleteLabel(input: $input) {\n'
                '      id\n'
                '      name\n'
                '      color\n'
                '      type\n'
                '      investigations {\n'
                '        nextToken\n'
                '      }\n'
                '      userSettings {\n'
                '        nextToken\n'
                '      }\n'
                '    }\n'
                '  }\n',
 'deletelabellink': '\n'
                    '  mutation DeleteLabelLink($input: DeleteLabelLinkInput!) '
                    '{\n'
                    '    deleteLabelLink(input: $input) {\n'
                    '      id\n'
                    '      investigationID\n'
                    '      labelID\n'
                    '      label {\n'
                    '        id\n'
                    '        name\n'
                    '        color\n'
                    '        type\n'
                    '      }\n'
                    '      investigation {\n'
                    '        id\n'
                    '        title\n'
                    '        from\n'
                    '        createdAt\n'
                    '        currentState\n'
                    '        HumanID\n'
                    '        currentStateID\n'
                    '        severity\n'
                    '        priority\n'
                    '        location\n'
                    '        channelId\n'
                    '        updatedAt\n'
                    '        resolvedTime\n'
                    '        resolvedComment\n'
                    '        Symptoms\n'
                    '        meetingType\n'
                    '        meetingId\n'
                    '      }\n'
                    '    }\n'
                    '  }\n',
 'deleteleadboard': '\n'
                    '  mutation DeleteLeadBoard($input: DeleteLeadBoardInput!) '
                    '{\n'
                    '    deleteLeadBoard(input: $input) {\n'
                    '      id\n'
                    '      investigationId\n'
                    '      content\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '      investigation {\n'
                    '        id\n'
                    '        title\n'
                    '        from\n'
                    '        createdAt\n'
                    '        currentState\n'
                    '        HumanID\n'
                    '        currentStateID\n'
                    '        severity\n'
                    '        priority\n'
                    '        location\n'
                    '        channelId\n'
                    '        updatedAt\n'
                    '        resolvedTime\n'
                    '        resolvedComment\n'
                    '        Symptoms\n'
                    '        meetingType\n'
                    '        meetingId\n'
                    '      }\n'
                    '    }\n'
                    '  }\n',
 'deleteleadboardnode': '\n'
                        '  mutation DeleteLeadBoardNode($input: '
                        'DeleteLeadBoardNodeInput!) {\n'
                        '    deleteLeadBoardNode(input: $input) {\n'
                        '      id\n'
                        '      localID\n'
                        '      createdAt\n'
                        '      updatedAt\n'
                        '      author\n'
                        '      content\n'
                        '      title\n'
                        '      notes\n'
                        '      associatedPlaybooks\n'
                        '      associatedCommands\n'
                        '      InvestLinks {\n'
                        '        nextToken\n'
                        '      }\n'
                        '    }\n'
                        '  }\n',
 'deletemessage': '\n'
                  '  mutation DeleteMessage($input: DeleteMessageInput!) {\n'
                  '    deleteMessage(input: $input) {\n'
                  '      id\n'
                  '      authorId\n'
                  '      content\n'
                  '      type\n'
                  '      channel {\n'
                  '        id\n'
                  '        name\n'
                  '        title\n'
                  '        members\n'
                  '        membersState\n'
                  '        createdAt\n'
                  '        updatedAt\n'
                  '        memberLocation\n'
                  '      }\n'
                  '      messageChannelId\n'
                  '      createdAt\n'
                  '      updatedAt\n'
                  '      author {\n'
                  '        id\n'
                  '        username\n'
                  '        email\n'
                  '        firstname\n'
                  '        lastname\n'
                  '        avatar\n'
                  '        mood\n'
                  '        name\n'
                  '        role\n'
                  '        status\n'
                  '        timezone\n'
                  '        phone\n'
                  '        address\n'
                  '        location\n'
                  '        createdAt\n'
                  '        updatedAt\n'
                  '        owner\n'
                  '      }\n'
                  '    }\n'
                  '  }\n',
 'deletemmnodelink': '\n'
                     '  mutation DeleteMmNodeLink($input: '
                     'DeleteMMNodeLinkInput!) {\n'
                     '    deleteMMNodeLink(input: $input) {\n'
                     '      id\n'
                     '      createdAt\n'
                     '      updatedAt\n'
                     '      assigned\n'
                     '      state\n'
                     '      content\n'
                     '      author\n'
                     '      investigationID\n'
                     '      connectionToTask\n'
                     '      LBNID\n'
                     '      LeadBoardNodeId {\n'
                     '        id\n'
                     '        localID\n'
                     '        createdAt\n'
                     '        updatedAt\n'
                     '        author\n'
                     '        content\n'
                     '        title\n'
                     '        notes\n'
                     '        associatedPlaybooks\n'
                     '        associatedCommands\n'
                     '      }\n'
                     '      investigationId {\n'
                     '        id\n'
                     '        title\n'
                     '        from\n'
                     '        createdAt\n'
                     '        currentState\n'
                     '        HumanID\n'
                     '        currentStateID\n'
                     '        severity\n'
                     '        priority\n'
                     '        location\n'
                     '        channelId\n'
                     '        updatedAt\n'
                     '        resolvedTime\n'
                     '        resolvedComment\n'
                     '        Symptoms\n'
                     '        meetingType\n'
                     '        meetingId\n'
                     '      }\n'
                     '    }\n'
                     '  }\n',
 'deletenotification': '\n'
                       '  mutation DeleteNotification($input: '
                       'DeleteNotificationInput!) {\n'
                       '    deleteNotification(input: $input) {\n'
                       '      id\n'
                       '      userName\n'
                       '      content\n'
                       '      containerType\n'
                       '      containerId\n'
                       '      investigationId\n'
                       '      isViewed\n'
                       '      createdAt\n'
                       '      updatedAt\n'
                       '    }\n'
                       '  }\n',
 'deletepin': '\n'
              '  mutation DeletePin($input: DeletePinInput!) {\n'
              '    deletePin(input: $input) {\n'
              '      id\n'
              '      imageId\n'
              '      content\n'
              '      createdAt\n'
              '      updatedAt\n'
              '      author\n'
              '      investigationId\n'
              '      investigation {\n'
              '        id\n'
              '        title\n'
              '        from\n'
              '        createdAt\n'
              '        currentState\n'
              '        HumanID\n'
              '        currentStateID\n'
              '        severity\n'
              '        priority\n'
              '        location\n'
              '        channelId\n'
              '        updatedAt\n'
              '        resolvedTime\n'
              '        resolvedComment\n'
              '        Symptoms\n'
              '        meetingType\n'
              '        meetingId\n'
              '      }\n'
              '    }\n'
              '  }\n',
 'deleteprivatekey': '\n'
                     '  mutation DeletePrivateKey($input: '
                     'DeletePrivateKeyInput!) {\n'
                     '    deletePrivateKey(input: $input) {\n'
                     '      id\n'
                     '      sshKey\n'
                     '      userName\n'
                     '      createdAt\n'
                     '      updatedAt\n'
                     '    }\n'
                     '  }\n',
 'deleteremotecontrol': '\n'
                        '  mutation DeleteRemoteControl($input: '
                        'DeleteRemoteControlInput!) {\n'
                        '    deleteRemoteControl(input: $input) {\n'
                        '      id\n'
                        '      from\n'
                        '      to\n'
                        '      command\n'
                        '      createdAt\n'
                        '      updatedAt\n'
                        '    }\n'
                        '  }\n',
 'deletereportsummaryeditor': '\n'
                              '  mutation DeleteReportSummaryEditor($input: '
                              'DeleteReportSummaryEditorInput!) {\n'
                              '    deleteReportSummaryEditor(input: $input) {\n'
                              '      id\n'
                              '      investigationId\n'
                              '      createdAt\n'
                              '      updatedAt\n'
                              '      author\n'
                              '      content\n'
                              '      type\n'
                              '    }\n'
                              '  }\n',
 'deleterunbookconnectorformlink': '\n'
                                   '  mutation '
                                   'DeleteRunbookConnectorFormLink(\n'
                                   '    $input: '
                                   'DeleteRunbookConnectorFormLinkInput!\n'
                                   '  ) {\n'
                                   '    deleteRunbookConnectorFormLink(input: '
                                   '$input) {\n'
                                   '      id\n'
                                   '      connectorFormId\n'
                                   '      runbookId\n'
                                   '      connectorForm {\n'
                                   '        id\n'
                                   '        createdAt\n'
                                   '        updatedAt\n'
                                   '        name\n'
                                   '        owner\n'
                                   '        connectorID\n'
                                   '        configData\n'
                                   '        commandData\n'
                                   '        nodeData\n'
                                   '        scope\n'
                                   '        PeopleCanView\n'
                                   '        PeopleCanAccess\n'
                                   '        GroupsCanView\n'
                                   '        GroupsCanAccess\n'
                                   '      }\n'
                                   '      runbook {\n'
                                   '        id\n'
                                   '        name\n'
                                   '        description\n'
                                   '        content\n'
                                   '        author\n'
                                   '        commands\n'
                                   '        createdAt\n'
                                   '        updatedAt\n'
                                   '        RunBookConnectors\n'
                                   '        type\n'
                                   '        longSave\n'
                                   '        rbVars\n'
                                   '        scope\n'
                                   '        PeopleCanView\n'
                                   '        PeopleCanAccess\n'
                                   '        GroupsCanView\n'
                                   '        GroupsCanAccess\n'
                                   '      }\n'
                                   '    }\n'
                                   '  }\n',
 'deleteschedpbs': '\n'
                   '  mutation DeleteSchedPBs($input: DeleteSchedPBsInput!) {\n'
                   '    deleteSchedPBs(input: $input) {\n'
                   '      id\n'
                   '      pbId\n'
                   '      frequency\n'
                   '      pbName\n'
                   '      rbVars\n'
                   '      scheduled\n'
                   '      createdAt\n'
                   '      updatedAt\n'
                   '      author\n'
                   '    }\n'
                   '  }\n',
 'deleteslackchannelinfo': '\n'
                           '  mutation DeleteSlackChannelInfo($input: '
                           'DeleteSlackChannelInfoInput!) {\n'
                           '    deleteSlackChannelInfo(input: $input) {\n'
                           '      id\n'
                           '      owner\n'
                           '      slackChannelId\n'
                           '      slackAppId\n'
                           '      slackTeamId\n'
                           '      slackTeam {\n'
                           '        id\n'
                           '        owner\n'
                           '        teamId\n'
                           '        teamName\n'
                           '        slackAppId\n'
                           '        botId\n'
                           '        botToken\n'
                           '        botScope\n'
                           '        enterprise\n'
                           '      }\n'
                           '      usersEnabled {\n'
                           '        nextToken\n'
                           '      }\n'
                           '    }\n'
                           '  }\n',
 'deleteslackenabledchannelsuserlink': '\n'
                                       '  mutation '
                                       'DeleteSlackEnabledChannelsUserLink(\n'
                                       '    $input: '
                                       'DeleteSlackEnabledChannelsUserLinkInput!\n'
                                       '  ) {\n'
                                       '    '
                                       'deleteSlackEnabledChannelsUserLink(input: '
                                       '$input) {\n'
                                       '      id\n'
                                       '      owner\n'
                                       '      slackUserId\n'
                                       '      slackChannelId\n'
                                       '      slackUser {\n'
                                       '        id\n'
                                       '        userAppSyncId\n'
                                       '        userName\n'
                                       '        userId\n'
                                       '        userScope\n'
                                       '        userToken\n'
                                       '        slackAppId\n'
                                       '        slackTeamId\n'
                                       '      }\n'
                                       '      slackChannel {\n'
                                       '        id\n'
                                       '        owner\n'
                                       '        slackChannelId\n'
                                       '        slackAppId\n'
                                       '        slackTeamId\n'
                                       '      }\n'
                                       '    }\n'
                                       '  }\n',
 'deleteslackteaminfo': '\n'
                        '  mutation DeleteSlackTeamInfo($input: '
                        'DeleteSlackTeamInfoInput!) {\n'
                        '    deleteSlackTeamInfo(input: $input) {\n'
                        '      id\n'
                        '      owner\n'
                        '      teamId\n'
                        '      teamName\n'
                        '      slackAppId\n'
                        '      botId\n'
                        '      botToken\n'
                        '      botScope\n'
                        '      enterprise\n'
                        '    }\n'
                        '  }\n',
 'deleteslackuserinfo': '\n'
                        '  mutation DeleteSlackUserInfo($input: '
                        'DeleteSlackUserInfoInput!) {\n'
                        '    deleteSlackUserInfo(input: $input) {\n'
                        '      id\n'
                        '      userAppSyncId\n'
                        '      userName\n'
                        '      userId\n'
                        '      userScope\n'
                        '      userToken\n'
                        '      slackAppId\n'
                        '      slackTeamId\n'
                        '      userGqlInfo {\n'
                        '        id\n'
                        '        username\n'
                        '        email\n'
                        '        firstname\n'
                        '        lastname\n'
                        '        avatar\n'
                        '        mood\n'
                        '        name\n'
                        '        role\n'
                        '        status\n'
                        '        timezone\n'
                        '        phone\n'
                        '        address\n'
                        '        location\n'
                        '        createdAt\n'
                        '        updatedAt\n'
                        '        owner\n'
                        '      }\n'
                        '      slackTeam {\n'
                        '        id\n'
                        '        owner\n'
                        '        teamId\n'
                        '        teamName\n'
                        '        slackAppId\n'
                        '        botId\n'
                        '        botToken\n'
                        '        botScope\n'
                        '        enterprise\n'
                        '      }\n'
                        '      channelsEnabled {\n'
                        '        nextToken\n'
                        '      }\n'
                        '    }\n'
                        '  }\n',
 'deletesshtabs': '\n'
                  '  mutation DeleteSshTabs($input: DeleteSshTabsInput!) {\n'
                  '    deleteSshTabs(input: $input) {\n'
                  '      id\n'
                  '      investigationId\n'
                  '      host\n'
                  '      author\n'
                  '      userName\n'
                  '      createdAt\n'
                  '      updatedAt\n'
                  '    }\n'
                  '  }\n',
 'deletestash': '\n'
                '  mutation DeleteStash($input: DeleteStashInput!) {\n'
                '    deleteStash(input: $input) {\n'
                '      id\n'
                '      Key\n'
                '      Value\n'
                '      createdAt\n'
                '      updatedAt\n'
                '      author\n'
                '      scope\n'
                '      PeopleCanView\n'
                '      PeopleCanAccess\n'
                '      GroupsCanView\n'
                '      GroupsCanAccess\n'
                '    }\n'
                '  }\n',
 'deletestate': '\n'
                '  mutation DeleteState($input: DeleteStateInput!) {\n'
                '    deleteState(input: $input) {\n'
                '      id\n'
                '      name\n'
                '      createdAt\n'
                '      updatedAt\n'
                '      author\n'
                '      lastState\n'
                '      investigationId\n'
                '      investigation {\n'
                '        id\n'
                '        title\n'
                '        from\n'
                '        createdAt\n'
                '        currentState\n'
                '        HumanID\n'
                '        currentStateID\n'
                '        severity\n'
                '        priority\n'
                '        location\n'
                '        channelId\n'
                '        updatedAt\n'
                '        resolvedTime\n'
                '        resolvedComment\n'
                '        Symptoms\n'
                '        meetingType\n'
                '        meetingId\n'
                '      }\n'
                '    }\n'
                '  }\n',
 'deletesummaryinvestigation': '\n'
                               '  mutation DeleteSummaryInvestigation(\n'
                               '    $input: DeleteSummaryInvestigationInput!\n'
                               '  ) {\n'
                               '    deleteSummaryInvestigation(input: $input) '
                               '{\n'
                               '      id\n'
                               '      createdAt\n'
                               '      updatedAt\n'
                               '      resolvedTime\n'
                               '      OriginalID\n'
                               '      title\n'
                               '      HumanID\n'
                               '      Commands\n'
                               '      InvestigationEvents\n'
                               '      CompleteInvestigationEvents\n'
                               '      Participants\n'
                               '      Comments\n'
                               '      Pins\n'
                               '      AvailableRunbooks\n'
                               '      UsedRunbooks\n'
                               '      Hints\n'
                               '      Symptoms\n'
                               '      owner\n'
                               '    }\n'
                               '  }\n',
 'deletetenantcustomer': '\n'
                         '  mutation DeleteTenantCustomer($input: '
                         'DeleteTenantCustomerInput!) {\n'
                         '    deleteTenantCustomer(input: $input) {\n'
                         '      label\n'
                         '      impactLabels\n'
                         '      createdAt\n'
                         '      updatedAt\n'
                         '      customerName\n'
                         '      email\n'
                         '      phoneno\n'
                         '      SLAType\n'
                         '      city\n'
                         '      state\n'
                         '      contry\n'
                         '      zipcode\n'
                         '    }\n'
                         '  }\n',
 'deletetranscriptionrecords': '\n'
                               '  mutation DeleteTranscriptionRecords(\n'
                               '    $input: DeleteTranscriptionRecordsInput!\n'
                               '  ) {\n'
                               '    deleteTranscriptionRecords(input: $input) '
                               '{\n'
                               '      id\n'
                               '      investigationId\n'
                               '      createdAt\n'
                               '      updatedAt\n'
                               '      spokenBy\n'
                               '      content\n'
                               '    }\n'
                               '  }\n',
 'deleteusedtogenhintalready': '\n'
                               '  mutation DeleteUsedToGenHintAlready(\n'
                               '    $input: DeleteUsedToGenHintAlreadyInput!\n'
                               '  ) {\n'
                               '    deleteUsedToGenHintAlready(input: $input) '
                               '{\n'
                               '      id\n'
                               '      createdAt\n'
                               '      updatedAt\n'
                               '      investigationId\n'
                               '      commands\n'
                               '      text\n'
                               '      investigation {\n'
                               '        id\n'
                               '        title\n'
                               '        from\n'
                               '        createdAt\n'
                               '        currentState\n'
                               '        HumanID\n'
                               '        currentStateID\n'
                               '        severity\n'
                               '        priority\n'
                               '        location\n'
                               '        channelId\n'
                               '        updatedAt\n'
                               '        resolvedTime\n'
                               '        resolvedComment\n'
                               '        Symptoms\n'
                               '        meetingType\n'
                               '        meetingId\n'
                               '      }\n'
                               '    }\n'
                               '  }\n',
 'deleteuser': '\n'
               '  mutation DeleteUser($input: DeleteUserInput!) {\n'
               '    deleteUser(input: $input) {\n'
               '      id\n'
               '      username\n'
               '      email\n'
               '      firstname\n'
               '      lastname\n'
               '      avatar\n'
               '      mood\n'
               '      name\n'
               '      role\n'
               '      status\n'
               '      timezone\n'
               '      phone\n'
               '      address\n'
               '      location\n'
               '      chatList {\n'
               '        nextToken\n'
               '      }\n'
               '      messages {\n'
               '        nextToken\n'
               '      }\n'
               '      createdAt\n'
               '      updatedAt\n'
               '      owner\n'
               '    }\n'
               '  }\n',
 'deleteuseractivity': '\n'
                       '  mutation DeleteUserActivity($input: '
                       'DeleteUserActivityInput!) {\n'
                       '    deleteUserActivity(input: $input) {\n'
                       '      id\n'
                       '      userID\n'
                       '      status\n'
                       '      investigationID\n'
                       '      createdAt\n'
                       '      updatedAt\n'
                       '      investigation {\n'
                       '        id\n'
                       '        title\n'
                       '        from\n'
                       '        createdAt\n'
                       '        currentState\n'
                       '        HumanID\n'
                       '        currentStateID\n'
                       '        severity\n'
                       '        priority\n'
                       '        location\n'
                       '        channelId\n'
                       '        updatedAt\n'
                       '        resolvedTime\n'
                       '        resolvedComment\n'
                       '        Symptoms\n'
                       '        meetingType\n'
                       '        meetingId\n'
                       '      }\n'
                       '      user {\n'
                       '        id\n'
                       '        username\n'
                       '        email\n'
                       '        firstname\n'
                       '        lastname\n'
                       '        avatar\n'
                       '        mood\n'
                       '        name\n'
                       '        role\n'
                       '        status\n'
                       '        timezone\n'
                       '        phone\n'
                       '        address\n'
                       '        location\n'
                       '        createdAt\n'
                       '        updatedAt\n'
                       '        owner\n'
                       '      }\n'
                       '    }\n'
                       '  }\n',
 'deleteusersetting': '\n'
                      '  mutation DeleteUserSetting($input: '
                      'DeleteUserSettingInput!) {\n'
                      '    deleteUserSetting(input: $input) {\n'
                      '      id\n'
                      '      userId\n'
                      '      owner\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '      labels {\n'
                      '        nextToken\n'
                      '      }\n'
                      '      value\n'
                      '      url\n'
                      '      name\n'
                      '      type\n'
                      '      showWelcomeNext\n'
                      '      showWelcomeSkip\n'
                      '      showWelcomeRemind\n'
                      '      welcomeData\n'
                      '    }\n'
                      '  }\n',
 'deleteusersettinglabellink': '\n'
                               '  mutation DeleteUserSettingLabelLink(\n'
                               '    $input: DeleteUserSettingLabelLinkInput!\n'
                               '  ) {\n'
                               '    deleteUserSettingLabelLink(input: $input) '
                               '{\n'
                               '      id\n'
                               '      userSettingId\n'
                               '      userSetting {\n'
                               '        id\n'
                               '        userId\n'
                               '        owner\n'
                               '        createdAt\n'
                               '        updatedAt\n'
                               '        value\n'
                               '        url\n'
                               '        name\n'
                               '        type\n'
                               '        showWelcomeNext\n'
                               '        showWelcomeSkip\n'
                               '        showWelcomeRemind\n'
                               '        welcomeData\n'
                               '      }\n'
                               '      labelID\n'
                               '      label {\n'
                               '        id\n'
                               '        name\n'
                               '        color\n'
                               '        type\n'
                               '      }\n'
                               '      type\n'
                               '    }\n'
                               '  }\n',
 'updatealertapikey': '\n'
                      '  mutation UpdateAlertApiKey($input: '
                      'UpdateAlertApiKeyInput!) {\n'
                      '    updateAlertApiKey(input: $input) {\n'
                      '      id\n'
                      '      alertsPbName\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '      author\n'
                      '    }\n'
                      '  }\n',
 'updateallrunbooks': '\n'
                      '  mutation UpdateAllRunbooks($input: '
                      'UpdateAllRunbooksInput!) {\n'
                      '    updateAllRunbooks(input: $input) {\n'
                      '      id\n'
                      '      name\n'
                      '      description\n'
                      '      content\n'
                      '      author\n'
                      '      commands\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '      RunBookConnectors\n'
                      '      type\n'
                      '      longSave\n'
                      '      rbVars\n'
                      '      scope\n'
                      '      PeopleCanView\n'
                      '      PeopleCanAccess\n'
                      '      GroupsCanView\n'
                      '      GroupsCanAccess\n'
                      '      connectorForms {\n'
                      '        nextToken\n'
                      '      }\n'
                      '    }\n'
                      '  }\n',
 'updateallworkflows': '\n'
                       '  mutation UpdateAllWorkflows($input: '
                       'UpdateAllWorkflowsInput!) {\n'
                       '    updateAllWorkflows(input: $input) {\n'
                       '      id\n'
                       '      createdAt\n'
                       '      updatedAt\n'
                       '      name\n'
                       '      description\n'
                       '      type\n'
                       '      author\n'
                       '      longSave\n'
                       '      rbVars\n'
                       '    }\n'
                       '  }\n',
 'updatebase64image': '\n'
                      '  mutation UpdateBase64Image($input: '
                      'UpdateBase64ImageInput!) {\n'
                      '    updateBase64Image(input: $input) {\n'
                      '      id\n'
                      '      playbookID\n'
                      '      base64String\n'
                      '    }\n'
                      '  }\n',
 'updatechannel': '\n'
                  '  mutation UpdateChannel($input: UpdateChannelInput!) {\n'
                  '    updateChannel(input: $input) {\n'
                  '      id\n'
                  '      messages {\n'
                  '        nextToken\n'
                  '      }\n'
                  '      associated {\n'
                  '        nextToken\n'
                  '      }\n'
                  '      name\n'
                  '      title\n'
                  '      members\n'
                  '      membersState\n'
                  '      createdAt\n'
                  '      updatedAt\n'
                  '      memberLocation\n'
                  '    }\n'
                  '  }\n',
 'updatechannellink': '\n'
                      '  mutation UpdateChannelLink($input: '
                      'UpdateChannelLinkInput!) {\n'
                      '    updateChannelLink(input: $input) {\n'
                      '      id\n'
                      '      contactId\n'
                      '      channel {\n'
                      '        id\n'
                      '        name\n'
                      '        title\n'
                      '        members\n'
                      '        membersState\n'
                      '        createdAt\n'
                      '        updatedAt\n'
                      '        memberLocation\n'
                      '      }\n'
                      '      chatId\n'
                      '      unread\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '      user {\n'
                      '        id\n'
                      '        username\n'
                      '        email\n'
                      '        firstname\n'
                      '        lastname\n'
                      '        avatar\n'
                      '        mood\n'
                      '        name\n'
                      '        role\n'
                      '        status\n'
                      '        timezone\n'
                      '        phone\n'
                      '        address\n'
                      '        location\n'
                      '        createdAt\n'
                      '        updatedAt\n'
                      '        owner\n'
                      '      }\n'
                      '    }\n'
                      '  }\n',
 'updatechat': '\n'
               '  mutation UpdateChat($input: UpdateChatInput!) {\n'
               '    updateChat(input: $input) {\n'
               '      id\n'
               '      from\n'
               '      content\n'
               '      createdAt\n'
               '    }\n'
               '  }\n',
 'updatecheatsheet': '\n'
                     '  mutation UpdateCheatSheet($input: '
                     'UpdateCheatSheetInput!) {\n'
                     '    updateCheatSheet(input: $input) {\n'
                     '      id\n'
                     '      createdAt\n'
                     '      updatedAt\n'
                     '      title\n'
                     '      author\n'
                     '      content\n'
                     '      type\n'
                     '    }\n'
                     '  }\n',
 'updatechecklist': '\n'
                    '  mutation UpdateCheckList($input: UpdateCheckListInput!) '
                    '{\n'
                    '    updateCheckList(input: $input) {\n'
                    '      id\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '      name\n'
                    '      description\n'
                    '      type\n'
                    '      content\n'
                    '      author\n'
                    '      CheckListLink {\n'
                    '        nextToken\n'
                    '      }\n'
                    '      CheckListInvLink {\n'
                    '        nextToken\n'
                    '      }\n'
                    '    }\n'
                    '  }\n',
 'updatechecklistinvlink': '\n'
                           '  mutation UpdateCheckListInvLink($input: '
                           'UpdateCheckListInvLinkInput!) {\n'
                           '    updateCheckListInvLink(input: $input) {\n'
                           '      id\n'
                           '      createdAt\n'
                           '      updatedAt\n'
                           '      investigationID\n'
                           '      CheckListID\n'
                           '      CheckList {\n'
                           '        id\n'
                           '        createdAt\n'
                           '        updatedAt\n'
                           '        name\n'
                           '        description\n'
                           '        type\n'
                           '        content\n'
                           '        author\n'
                           '      }\n'
                           '      investigation {\n'
                           '        id\n'
                           '        title\n'
                           '        from\n'
                           '        createdAt\n'
                           '        currentState\n'
                           '        HumanID\n'
                           '        currentStateID\n'
                           '        severity\n'
                           '        priority\n'
                           '        location\n'
                           '        channelId\n'
                           '        updatedAt\n'
                           '        resolvedTime\n'
                           '        resolvedComment\n'
                           '        Symptoms\n'
                           '        meetingType\n'
                           '        meetingId\n'
                           '      }\n'
                           '      owner\n'
                           '    }\n'
                           '  }\n',
 'updatechecklistitem': '\n'
                        '  mutation UpdateCheckListItem($input: '
                        'UpdateCheckListItemInput!) {\n'
                        '    updateCheckListItem(input: $input) {\n'
                        '      id\n'
                        '      localID\n'
                        '      createdAt\n'
                        '      updatedAt\n'
                        '      author\n'
                        '      content\n'
                        '      title\n'
                        '      type\n'
                        '      connection\n'
                        '      MMNodeConnection\n'
                        '      investigationID\n'
                        '      assignee\n'
                        '      associatedPlaybooks\n'
                        '      associatedCommands\n'
                        '      CheckListLink {\n'
                        '        nextToken\n'
                        '      }\n'
                        '    }\n'
                        '  }\n',
 'updateclick': '\n'
                '  mutation UpdateClick($input: UpdateClickInput!) {\n'
                '    updateClick(input: $input) {\n'
                '      id\n'
                '      count\n'
                '      type\n'
                '      featureName\n'
                '      createdAt\n'
                '      updatedAt\n'
                '      readAt\n'
                '    }\n'
                '  }\n',
 'updateclicllink': '\n'
                    '  mutation UpdateCliclLink($input: UpdateCLICLLinkInput!) '
                    '{\n'
                    '    updateCLICLLink(input: $input) {\n'
                    '      id\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '      CheckListItemID\n'
                    '      lane\n'
                    '      CheckListID\n'
                    '      CheckList {\n'
                    '        id\n'
                    '        createdAt\n'
                    '        updatedAt\n'
                    '        name\n'
                    '        description\n'
                    '        type\n'
                    '        content\n'
                    '        author\n'
                    '      }\n'
                    '      CheckListItem {\n'
                    '        id\n'
                    '        localID\n'
                    '        createdAt\n'
                    '        updatedAt\n'
                    '        author\n'
                    '        content\n'
                    '        title\n'
                    '        type\n'
                    '        connection\n'
                    '        MMNodeConnection\n'
                    '        investigationID\n'
                    '        assignee\n'
                    '        associatedPlaybooks\n'
                    '        associatedCommands\n'
                    '      }\n'
                    '    }\n'
                    '  }\n',
 'updatecommands': '\n'
                   '  mutation UpdateCommands($input: UpdateCommandsInput!) {\n'
                   '    updateCommands(input: $input) {\n'
                   '      id\n'
                   '      from\n'
                   '      mode\n'
                   '      command\n'
                   '      output\n'
                   '      state\n'
                   '      returnCode\n'
                   '      investigationId\n'
                   '      createdAt\n'
                   '      updatedAt\n'
                   '      investigation {\n'
                   '        id\n'
                   '        title\n'
                   '        from\n'
                   '        createdAt\n'
                   '        currentState\n'
                   '        HumanID\n'
                   '        currentStateID\n'
                   '        severity\n'
                   '        priority\n'
                   '        location\n'
                   '        channelId\n'
                   '        updatedAt\n'
                   '        resolvedTime\n'
                   '        resolvedComment\n'
                   '        Symptoms\n'
                   '        meetingType\n'
                   '        meetingId\n'
                   '      }\n'
                   '    }\n'
                   '  }\n',
 'updatecomment': '\n'
                  '  mutation UpdateComment($input: UpdateCommentInput!) {\n'
                  '    updateComment(input: $input) {\n'
                  '      id\n'
                  '      parent\n'
                  '      createdAt\n'
                  '      updatedAt\n'
                  '      author\n'
                  '      content\n'
                  '      type\n'
                  '      links\n'
                  '      investigationId\n'
                  '      investigation {\n'
                  '        id\n'
                  '        title\n'
                  '        from\n'
                  '        createdAt\n'
                  '        currentState\n'
                  '        HumanID\n'
                  '        currentStateID\n'
                  '        severity\n'
                  '        priority\n'
                  '        location\n'
                  '        channelId\n'
                  '        updatedAt\n'
                  '        resolvedTime\n'
                  '        resolvedComment\n'
                  '        Symptoms\n'
                  '        meetingType\n'
                  '        meetingId\n'
                  '      }\n'
                  '    }\n'
                  '  }\n',
 'updateconferenceconfig': '\n'
                           '  mutation UpdateConferenceConfig($input: '
                           'UpdateConferenceConfigInput!) {\n'
                           '    updateConferenceConfig(input: $input) {\n'
                           '      id\n'
                           '      url\n'
                           '      userName\n'
                           '      password\n'
                           '      author\n'
                           '      createdAt\n'
                           '      updatedAt\n'
                           '    }\n'
                           '  }\n',
 'updateconnectorform': '\n'
                        '  mutation UpdateConnectorForm($input: '
                        'UpdateConnectorFormInput!) {\n'
                        '    updateConnectorForm(input: $input) {\n'
                        '      id\n'
                        '      createdAt\n'
                        '      updatedAt\n'
                        '      name\n'
                        '      owner\n'
                        '      connectorID\n'
                        '      connector {\n'
                        '        id\n'
                        '        createdAt\n'
                        '        updatedAt\n'
                        '        category\n'
                        '        name\n'
                        '        owner\n'
                        '        description\n'
                        '        detaileddescription\n'
                        '        iconPath\n'
                        '        version\n'
                        '        md5\n'
                        '        source\n'
                        '        configuration\n'
                        '        commands\n'
                        '        commandsType\n'
                        '        script\n'
                        '        scriptType\n'
                        '        scriptPath\n'
                        '        scope\n'
                        '        PeopleCanView\n'
                        '        PeopleCanAccess\n'
                        '        GroupsCanView\n'
                        '        GroupsCanAccess\n'
                        '      }\n'
                        '      configData\n'
                        '      commandData\n'
                        '      nodeData\n'
                        '      scope\n'
                        '      PeopleCanView\n'
                        '      PeopleCanAccess\n'
                        '      GroupsCanView\n'
                        '      GroupsCanAccess\n'
                        '      runbooks {\n'
                        '        nextToken\n'
                        '      }\n'
                        '    }\n'
                        '  }\n',
 'updateconnectors': '\n'
                     '  mutation UpdateConnectors($input: '
                     'UpdateConnectorsInput!) {\n'
                     '    updateConnectors(input: $input) {\n'
                     '      id\n'
                     '      createdAt\n'
                     '      updatedAt\n'
                     '      category\n'
                     '      name\n'
                     '      owner\n'
                     '      description\n'
                     '      detaileddescription\n'
                     '      iconPath\n'
                     '      version\n'
                     '      md5\n'
                     '      source\n'
                     '      configuration\n'
                     '      commands\n'
                     '      commandsType\n'
                     '      script\n'
                     '      scriptType\n'
                     '      scriptPath\n'
                     '      scope\n'
                     '      PeopleCanView\n'
                     '      PeopleCanAccess\n'
                     '      GroupsCanView\n'
                     '      GroupsCanAccess\n'
                     '    }\n'
                     '  }\n',
 'updatedashboardconfig': '\n'
                          '  mutation UpdateDashboardConfig($input: '
                          'UpdateDashboardConfigInput!) {\n'
                          '    updateDashboardConfig(input: $input) {\n'
                          '      id\n'
                          '      url\n'
                          '      labels {\n'
                          '        nextToken\n'
                          '      }\n'
                          '      author\n'
                          '      createdAt\n'
                          '      updatedAt\n'
                          '    }\n'
                          '  }\n',
 'updatedashboardconfiglabellink': '\n'
                                   '  mutation '
                                   'UpdateDashboardConfigLabelLink(\n'
                                   '    $input: '
                                   'UpdateDashboardConfigLabelLinkInput!\n'
                                   '  ) {\n'
                                   '    updateDashboardConfigLabelLink(input: '
                                   '$input) {\n'
                                   '      id\n'
                                   '      dashboardConfigID\n'
                                   '      labelID\n'
                                   '      dashboardConfig {\n'
                                   '        id\n'
                                   '        url\n'
                                   '        author\n'
                                   '        createdAt\n'
                                   '        updatedAt\n'
                                   '      }\n'
                                   '      label {\n'
                                   '        id\n'
                                   '        name\n'
                                   '        color\n'
                                   '        type\n'
                                   '      }\n'
                                   '    }\n'
                                   '  }\n',
 'updateecubesandboxexecution': '\n'
                                '  mutation UpdateEcubeSandboxExecution(\n'
                                '    $input: '
                                'UpdateEcubeSandboxExecutionInput!\n'
                                '  ) {\n'
                                '    updateEcubeSandboxExecution(input: '
                                '$input) {\n'
                                '      id\n'
                                '      owner\n'
                                '      output\n'
                                '      outputType\n'
                                '      returnCode\n'
                                '      status\n'
                                '      createdAt\n'
                                '      updatedAt\n'
                                '      E3One\n'
                                '      E3Two\n'
                                '      E3Three\n'
                                '    }\n'
                                '  }\n',
 'updateepicautocomplete': '\n'
                           '  mutation UpdateEpicAutoComplete($input: '
                           'UpdateEpicAutoCompleteInput!) {\n'
                           '    updateEpicAutoComplete(input: $input) {\n'
                           '      id\n'
                           '      author\n'
                           '      cliCommand\n'
                           '      command\n'
                           '      createdAt\n'
                           '      updatedAt\n'
                           '      investigationId\n'
                           '      times\n'
                           '    }\n'
                           '  }\n',
 'updateepiclicommand': '\n'
                        '  mutation UpdateEpicliCommand($input: '
                        'UpdateEPICLICommandInput!) {\n'
                        '    updateEPICLICommand(input: $input) {\n'
                        '      id\n'
                        '      createdAt\n'
                        '      updatedAt\n'
                        '      author\n'
                        '      content\n'
                        '      type\n'
                        '    }\n'
                        '  }\n',
 'updateexecutedrunbooks': '\n'
                           '  mutation UpdateExecutedRunbooks($input: '
                           'UpdateExecutedRunbooksInput!) {\n'
                           '    updateExecutedRunbooks(input: $input) {\n'
                           '      id\n'
                           '      createdAt\n'
                           '      updatedAt\n'
                           '      runbookID\n'
                           '      investigationId\n'
                           '      output\n'
                           '      outputType\n'
                           '      title\n'
                           '      state\n'
                           '      author\n'
                           '      rbVars\n'
                           '      callbackUrl\n'
                           '      callbackData\n'
                           '      source\n'
                           '      investigation {\n'
                           '        id\n'
                           '        title\n'
                           '        from\n'
                           '        createdAt\n'
                           '        currentState\n'
                           '        HumanID\n'
                           '        currentStateID\n'
                           '        severity\n'
                           '        priority\n'
                           '        location\n'
                           '        channelId\n'
                           '        updatedAt\n'
                           '        resolvedTime\n'
                           '        resolvedComment\n'
                           '        Symptoms\n'
                           '        meetingType\n'
                           '        meetingId\n'
                           '      }\n'
                           '      runbook {\n'
                           '        id\n'
                           '        name\n'
                           '        description\n'
                           '        content\n'
                           '        author\n'
                           '        commands\n'
                           '        createdAt\n'
                           '        updatedAt\n'
                           '        RunBookConnectors\n'
                           '        type\n'
                           '        longSave\n'
                           '        rbVars\n'
                           '        scope\n'
                           '        PeopleCanView\n'
                           '        PeopleCanAccess\n'
                           '        GroupsCanView\n'
                           '        GroupsCanAccess\n'
                           '      }\n'
                           '    }\n'
                           '  }\n',
 'updateexecutedworkflowstate': '\n'
                                '  mutation UpdateExecutedWorkflowState(\n'
                                '    $input: '
                                'UpdateExecutedWorkflowStateInput!\n'
                                '  ) {\n'
                                '    updateExecutedWorkflowState(input: '
                                '$input) {\n'
                                '      id\n'
                                '      createdAt\n'
                                '      updatedAt\n'
                                '      name\n'
                                '      state\n'
                                '      output\n'
                                '      type\n'
                                '      allworkflowID\n'
                                '      investigationID\n'
                                '      investigation {\n'
                                '        id\n'
                                '        title\n'
                                '        from\n'
                                '        createdAt\n'
                                '        currentState\n'
                                '        HumanID\n'
                                '        currentStateID\n'
                                '        severity\n'
                                '        priority\n'
                                '        location\n'
                                '        channelId\n'
                                '        updatedAt\n'
                                '        resolvedTime\n'
                                '        resolvedComment\n'
                                '        Symptoms\n'
                                '        meetingType\n'
                                '        meetingId\n'
                                '      }\n'
                                '    }\n'
                                '  }\n',
 'updategroupmember': '\n'
                      '  mutation UpdateGroupMember($input: '
                      'UpdateGroupMemberInput!) {\n'
                      '    updateGroupMember(input: $input) {\n'
                      '      id\n'
                      '      hostId\n'
                      '      groupId\n'
                      '      host {\n'
                      '        id\n'
                      '        inventoryId\n'
                      '        createdAt\n'
                      '        updatedAt\n'
                      '        author\n'
                      '        host\n'
                      '        port\n'
                      '        vars\n'
                      '      }\n'
                      '      group {\n'
                      '        id\n'
                      '        inventoryId\n'
                      '        createdAt\n'
                      '        updatedAt\n'
                      '        author\n'
                      '        name\n'
                      '        groups\n'
                      '        port\n'
                      '        vars\n'
                      '      }\n'
                      '    }\n'
                      '  }\n',
 'updateguardrail': '\n'
                    '  mutation UpdateGuardRail($input: UpdateGuardRailInput!) '
                    '{\n'
                    '    updateGuardRail(input: $input) {\n'
                    '      id\n'
                    '      timeOut\n'
                    '      message\n'
                    '      labels {\n'
                    '        nextToken\n'
                    '      }\n'
                    '      author\n'
                    '      active\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '    }\n'
                    '  }\n',
 'updateguardraillabellink': '\n'
                             '  mutation UpdateGuardRailLabelLink($input: '
                             'UpdateGuardRailLabelLinkInput!) {\n'
                             '    updateGuardRailLabelLink(input: $input) {\n'
                             '      id\n'
                             '      guardRailID\n'
                             '      labelID\n'
                             '      guardRail {\n'
                             '        id\n'
                             '        timeOut\n'
                             '        message\n'
                             '        author\n'
                             '        active\n'
                             '        createdAt\n'
                             '        updatedAt\n'
                             '      }\n'
                             '      label {\n'
                             '        id\n'
                             '        name\n'
                             '        color\n'
                             '        type\n'
                             '      }\n'
                             '    }\n'
                             '  }\n',
 'updatehint': '\n'
               '  mutation UpdateHint($input: UpdateHintInput!) {\n'
               '    updateHint(input: $input) {\n'
               '      id\n'
               '      investigationId\n'
               '      createdAt\n'
               '      updatedAt\n'
               '      type\n'
               '      connection\n'
               '      pastInvestigationID\n'
               '      title\n'
               '      importance\n'
               '      starrted\n'
               '      applied\n'
               '      url\n'
               '      why\n'
               '    }\n'
               '  }\n',
 'updateinventory': '\n'
                    '  mutation UpdateInventory($input: UpdateInventoryInput!) '
                    '{\n'
                    '    updateInventory(input: $input) {\n'
                    '      id\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '      author\n'
                    '      name\n'
                    '      all {\n'
                    '        nextToken\n'
                    '      }\n'
                    '      groups {\n'
                    '        nextToken\n'
                    '      }\n'
                    '      vars\n'
                    '    }\n'
                    '  }\n',
 'updateinventorygroup': '\n'
                         '  mutation UpdateInventoryGroup($input: '
                         'UpdateInventoryGroupInput!) {\n'
                         '    updateInventoryGroup(input: $input) {\n'
                         '      id\n'
                         '      inventoryId\n'
                         '      createdAt\n'
                         '      updatedAt\n'
                         '      author\n'
                         '      name\n'
                         '      hosts {\n'
                         '        nextToken\n'
                         '      }\n'
                         '      groups\n'
                         '      port\n'
                         '      vars\n'
                         '      inventory {\n'
                         '        id\n'
                         '        createdAt\n'
                         '        updatedAt\n'
                         '        author\n'
                         '        name\n'
                         '        vars\n'
                         '      }\n'
                         '    }\n'
                         '  }\n',
 'updateinventoryhost': '\n'
                        '  mutation UpdateInventoryHost($input: '
                        'UpdateInventoryHostInput!) {\n'
                        '    updateInventoryHost(input: $input) {\n'
                        '      id\n'
                        '      inventoryId\n'
                        '      createdAt\n'
                        '      updatedAt\n'
                        '      author\n'
                        '      host\n'
                        '      port\n'
                        '      vars\n'
                        '      groups {\n'
                        '        nextToken\n'
                        '      }\n'
                        '      inventory {\n'
                        '        id\n'
                        '        createdAt\n'
                        '        updatedAt\n'
                        '        author\n'
                        '        name\n'
                        '        vars\n'
                        '      }\n'
                        '    }\n'
                        '  }\n',
 'updateinvestigation': '\n'
                        '  mutation UpdateInvestigation($input: '
                        'UpdateInvestigationInput!) {\n'
                        '    updateInvestigation(input: $input) {\n'
                        '      id\n'
                        '      title\n'
                        '      from\n'
                        '      createdAt\n'
                        '      currentState\n'
                        '      HumanID\n'
                        '      currentStateID\n'
                        '      severity\n'
                        '      priority\n'
                        '      location\n'
                        '      labels {\n'
                        '        nextToken\n'
                        '      }\n'
                        '      channelId\n'
                        '      investigationChannel {\n'
                        '        id\n'
                        '        name\n'
                        '        title\n'
                        '        members\n'
                        '        membersState\n'
                        '        createdAt\n'
                        '        updatedAt\n'
                        '        memberLocation\n'
                        '      }\n'
                        '      updatedAt\n'
                        '      resolvedTime\n'
                        '      resolvedComment\n'
                        '      Symptoms\n'
                        '      MMNodeLinks {\n'
                        '        nextToken\n'
                        '      }\n'
                        '      CheckListInvLink {\n'
                        '        nextToken\n'
                        '      }\n'
                        '      meetingType\n'
                        '      meetingId\n'
                        '    }\n'
                        '  }\n',
 'updateinvestigationevent': '\n'
                             '  mutation UpdateInvestigationEvent($input: '
                             'UpdateInvestigationEventInput!) {\n'
                             '    updateInvestigationEvent(input: $input) {\n'
                             '      id\n'
                             '      createdAt\n'
                             '      updatedAt\n'
                             '      author\n'
                             '      content\n'
                             '      type\n'
                             '      links\n'
                             '      investigationId\n'
                             '      investigation {\n'
                             '        id\n'
                             '        title\n'
                             '        from\n'
                             '        createdAt\n'
                             '        currentState\n'
                             '        HumanID\n'
                             '        currentStateID\n'
                             '        severity\n'
                             '        priority\n'
                             '        location\n'
                             '        channelId\n'
                             '        updatedAt\n'
                             '        resolvedTime\n'
                             '        resolvedComment\n'
                             '        Symptoms\n'
                             '        meetingType\n'
                             '        meetingId\n'
                             '      }\n'
                             '    }\n'
                             '  }\n',
 'updateinvestigationguestuserlink': '\n'
                                     '  mutation '
                                     'UpdateInvestigationGuestUserLink(\n'
                                     '    $input: '
                                     'UpdateInvestigationGuestUserLinkInput!\n'
                                     '  ) {\n'
                                     '    '
                                     'updateInvestigationGuestUserLink(input: '
                                     '$input) {\n'
                                     '      id\n'
                                     '      userName\n'
                                     '      createdAt\n'
                                     '      updatedAt\n'
                                     '      investigationID\n'
                                     '      channelID\n'
                                     '    }\n'
                                     '  }\n',
 'updatelabel': '\n'
                '  mutation UpdateLabel($input: UpdateLabelInput!) {\n'
                '    updateLabel(input: $input) {\n'
                '      id\n'
                '      name\n'
                '      color\n'
                '      type\n'
                '      investigations {\n'
                '        nextToken\n'
                '      }\n'
                '      userSettings {\n'
                '        nextToken\n'
                '      }\n'
                '    }\n'
                '  }\n',
 'updatelabellink': '\n'
                    '  mutation UpdateLabelLink($input: UpdateLabelLinkInput!) '
                    '{\n'
                    '    updateLabelLink(input: $input) {\n'
                    '      id\n'
                    '      investigationID\n'
                    '      labelID\n'
                    '      label {\n'
                    '        id\n'
                    '        name\n'
                    '        color\n'
                    '        type\n'
                    '      }\n'
                    '      investigation {\n'
                    '        id\n'
                    '        title\n'
                    '        from\n'
                    '        createdAt\n'
                    '        currentState\n'
                    '        HumanID\n'
                    '        currentStateID\n'
                    '        severity\n'
                    '        priority\n'
                    '        location\n'
                    '        channelId\n'
                    '        updatedAt\n'
                    '        resolvedTime\n'
                    '        resolvedComment\n'
                    '        Symptoms\n'
                    '        meetingType\n'
                    '        meetingId\n'
                    '      }\n'
                    '    }\n'
                    '  }\n',
 'updateleadboard': '\n'
                    '  mutation UpdateLeadBoard($input: UpdateLeadBoardInput!) '
                    '{\n'
                    '    updateLeadBoard(input: $input) {\n'
                    '      id\n'
                    '      investigationId\n'
                    '      content\n'
                    '      createdAt\n'
                    '      updatedAt\n'
                    '      investigation {\n'
                    '        id\n'
                    '        title\n'
                    '        from\n'
                    '        createdAt\n'
                    '        currentState\n'
                    '        HumanID\n'
                    '        currentStateID\n'
                    '        severity\n'
                    '        priority\n'
                    '        location\n'
                    '        channelId\n'
                    '        updatedAt\n'
                    '        resolvedTime\n'
                    '        resolvedComment\n'
                    '        Symptoms\n'
                    '        meetingType\n'
                    '        meetingId\n'
                    '      }\n'
                    '    }\n'
                    '  }\n',
 'updateleadboardnode': '\n'
                        '  mutation UpdateLeadBoardNode($input: '
                        'UpdateLeadBoardNodeInput!) {\n'
                        '    updateLeadBoardNode(input: $input) {\n'
                        '      id\n'
                        '      localID\n'
                        '      createdAt\n'
                        '      updatedAt\n'
                        '      author\n'
                        '      content\n'
                        '      title\n'
                        '      notes\n'
                        '      associatedPlaybooks\n'
                        '      associatedCommands\n'
                        '      InvestLinks {\n'
                        '        nextToken\n'
                        '      }\n'
                        '    }\n'
                        '  }\n',
 'updatemessage': '\n'
                  '  mutation UpdateMessage($input: UpdateMessageInput!) {\n'
                  '    updateMessage(input: $input) {\n'
                  '      id\n'
                  '      authorId\n'
                  '      content\n'
                  '      type\n'
                  '      channel {\n'
                  '        id\n'
                  '        name\n'
                  '        title\n'
                  '        members\n'
                  '        membersState\n'
                  '        createdAt\n'
                  '        updatedAt\n'
                  '        memberLocation\n'
                  '      }\n'
                  '      messageChannelId\n'
                  '      createdAt\n'
                  '      updatedAt\n'
                  '      author {\n'
                  '        id\n'
                  '        username\n'
                  '        email\n'
                  '        firstname\n'
                  '        lastname\n'
                  '        avatar\n'
                  '        mood\n'
                  '        name\n'
                  '        role\n'
                  '        status\n'
                  '        timezone\n'
                  '        phone\n'
                  '        address\n'
                  '        location\n'
                  '        createdAt\n'
                  '        updatedAt\n'
                  '        owner\n'
                  '      }\n'
                  '    }\n'
                  '  }\n',
 'updatemmnodelink': '\n'
                     '  mutation UpdateMmNodeLink($input: '
                     'UpdateMMNodeLinkInput!) {\n'
                     '    updateMMNodeLink(input: $input) {\n'
                     '      id\n'
                     '      createdAt\n'
                     '      updatedAt\n'
                     '      assigned\n'
                     '      state\n'
                     '      content\n'
                     '      author\n'
                     '      investigationID\n'
                     '      connectionToTask\n'
                     '      LBNID\n'
                     '      LeadBoardNodeId {\n'
                     '        id\n'
                     '        localID\n'
                     '        createdAt\n'
                     '        updatedAt\n'
                     '        author\n'
                     '        content\n'
                     '        title\n'
                     '        notes\n'
                     '        associatedPlaybooks\n'
                     '        associatedCommands\n'
                     '      }\n'
                     '      investigationId {\n'
                     '        id\n'
                     '        title\n'
                     '        from\n'
                     '        createdAt\n'
                     '        currentState\n'
                     '        HumanID\n'
                     '        currentStateID\n'
                     '        severity\n'
                     '        priority\n'
                     '        location\n'
                     '        channelId\n'
                     '        updatedAt\n'
                     '        resolvedTime\n'
                     '        resolvedComment\n'
                     '        Symptoms\n'
                     '        meetingType\n'
                     '        meetingId\n'
                     '      }\n'
                     '    }\n'
                     '  }\n',
 'updatenotification': '\n'
                       '  mutation UpdateNotification($input: '
                       'UpdateNotificationInput!) {\n'
                       '    updateNotification(input: $input) {\n'
                       '      id\n'
                       '      userName\n'
                       '      content\n'
                       '      containerType\n'
                       '      containerId\n'
                       '      investigationId\n'
                       '      isViewed\n'
                       '      createdAt\n'
                       '      updatedAt\n'
                       '    }\n'
                       '  }\n',
 'updatepin': '\n'
              '  mutation UpdatePin($input: UpdatePinInput!) {\n'
              '    updatePin(input: $input) {\n'
              '      id\n'
              '      imageId\n'
              '      content\n'
              '      createdAt\n'
              '      updatedAt\n'
              '      author\n'
              '      investigationId\n'
              '      investigation {\n'
              '        id\n'
              '        title\n'
              '        from\n'
              '        createdAt\n'
              '        currentState\n'
              '        HumanID\n'
              '        currentStateID\n'
              '        severity\n'
              '        priority\n'
              '        location\n'
              '        channelId\n'
              '        updatedAt\n'
              '        resolvedTime\n'
              '        resolvedComment\n'
              '        Symptoms\n'
              '        meetingType\n'
              '        meetingId\n'
              '      }\n'
              '    }\n'
              '  }\n',
 'updateprivatekey': '\n'
                     '  mutation UpdatePrivateKey($input: '
                     'UpdatePrivateKeyInput!) {\n'
                     '    updatePrivateKey(input: $input) {\n'
                     '      id\n'
                     '      sshKey\n'
                     '      userName\n'
                     '      createdAt\n'
                     '      updatedAt\n'
                     '    }\n'
                     '  }\n',
 'updateremotecontrol': '\n'
                        '  mutation UpdateRemoteControl($input: '
                        'UpdateRemoteControlInput!) {\n'
                        '    updateRemoteControl(input: $input) {\n'
                        '      id\n'
                        '      from\n'
                        '      to\n'
                        '      command\n'
                        '      createdAt\n'
                        '      updatedAt\n'
                        '    }\n'
                        '  }\n',
 'updatereportsummaryeditor': '\n'
                              '  mutation UpdateReportSummaryEditor($input: '
                              'UpdateReportSummaryEditorInput!) {\n'
                              '    updateReportSummaryEditor(input: $input) {\n'
                              '      id\n'
                              '      investigationId\n'
                              '      createdAt\n'
                              '      updatedAt\n'
                              '      author\n'
                              '      content\n'
                              '      type\n'
                              '    }\n'
                              '  }\n',
 'updaterunbookconnectorformlink': '\n'
                                   '  mutation '
                                   'UpdateRunbookConnectorFormLink(\n'
                                   '    $input: '
                                   'UpdateRunbookConnectorFormLinkInput!\n'
                                   '  ) {\n'
                                   '    updateRunbookConnectorFormLink(input: '
                                   '$input) {\n'
                                   '      id\n'
                                   '      connectorFormId\n'
                                   '      runbookId\n'
                                   '      connectorForm {\n'
                                   '        id\n'
                                   '        createdAt\n'
                                   '        updatedAt\n'
                                   '        name\n'
                                   '        owner\n'
                                   '        connectorID\n'
                                   '        configData\n'
                                   '        commandData\n'
                                   '        nodeData\n'
                                   '        scope\n'
                                   '        PeopleCanView\n'
                                   '        PeopleCanAccess\n'
                                   '        GroupsCanView\n'
                                   '        GroupsCanAccess\n'
                                   '      }\n'
                                   '      runbook {\n'
                                   '        id\n'
                                   '        name\n'
                                   '        description\n'
                                   '        content\n'
                                   '        author\n'
                                   '        commands\n'
                                   '        createdAt\n'
                                   '        updatedAt\n'
                                   '        RunBookConnectors\n'
                                   '        type\n'
                                   '        longSave\n'
                                   '        rbVars\n'
                                   '        scope\n'
                                   '        PeopleCanView\n'
                                   '        PeopleCanAccess\n'
                                   '        GroupsCanView\n'
                                   '        GroupsCanAccess\n'
                                   '      }\n'
                                   '    }\n'
                                   '  }\n',
 'updateschedpbs': '\n'
                   '  mutation UpdateSchedPBs($input: UpdateSchedPBsInput!) {\n'
                   '    updateSchedPBs(input: $input) {\n'
                   '      id\n'
                   '      pbId\n'
                   '      frequency\n'
                   '      pbName\n'
                   '      rbVars\n'
                   '      scheduled\n'
                   '      createdAt\n'
                   '      updatedAt\n'
                   '      author\n'
                   '    }\n'
                   '  }\n',
 'updateslackchannelinfo': '\n'
                           '  mutation UpdateSlackChannelInfo($input: '
                           'UpdateSlackChannelInfoInput!) {\n'
                           '    updateSlackChannelInfo(input: $input) {\n'
                           '      id\n'
                           '      owner\n'
                           '      slackChannelId\n'
                           '      slackAppId\n'
                           '      slackTeamId\n'
                           '      slackTeam {\n'
                           '        id\n'
                           '        owner\n'
                           '        teamId\n'
                           '        teamName\n'
                           '        slackAppId\n'
                           '        botId\n'
                           '        botToken\n'
                           '        botScope\n'
                           '        enterprise\n'
                           '      }\n'
                           '      usersEnabled {\n'
                           '        nextToken\n'
                           '      }\n'
                           '    }\n'
                           '  }\n',
 'updateslackenabledchannelsuserlink': '\n'
                                       '  mutation '
                                       'UpdateSlackEnabledChannelsUserLink(\n'
                                       '    $input: '
                                       'UpdateSlackEnabledChannelsUserLinkInput!\n'
                                       '  ) {\n'
                                       '    '
                                       'updateSlackEnabledChannelsUserLink(input: '
                                       '$input) {\n'
                                       '      id\n'
                                       '      owner\n'
                                       '      slackUserId\n'
                                       '      slackChannelId\n'
                                       '      slackUser {\n'
                                       '        id\n'
                                       '        userAppSyncId\n'
                                       '        userName\n'
                                       '        userId\n'
                                       '        userScope\n'
                                       '        userToken\n'
                                       '        slackAppId\n'
                                       '        slackTeamId\n'
                                       '      }\n'
                                       '      slackChannel {\n'
                                       '        id\n'
                                       '        owner\n'
                                       '        slackChannelId\n'
                                       '        slackAppId\n'
                                       '        slackTeamId\n'
                                       '      }\n'
                                       '    }\n'
                                       '  }\n',
 'updateslackteaminfo': '\n'
                        '  mutation UpdateSlackTeamInfo($input: '
                        'UpdateSlackTeamInfoInput!) {\n'
                        '    updateSlackTeamInfo(input: $input) {\n'
                        '      id\n'
                        '      owner\n'
                        '      teamId\n'
                        '      teamName\n'
                        '      slackAppId\n'
                        '      botId\n'
                        '      botToken\n'
                        '      botScope\n'
                        '      enterprise\n'
                        '    }\n'
                        '  }\n',
 'updateslackuserinfo': '\n'
                        '  mutation UpdateSlackUserInfo($input: '
                        'UpdateSlackUserInfoInput!) {\n'
                        '    updateSlackUserInfo(input: $input) {\n'
                        '      id\n'
                        '      userAppSyncId\n'
                        '      userName\n'
                        '      userId\n'
                        '      userScope\n'
                        '      userToken\n'
                        '      slackAppId\n'
                        '      slackTeamId\n'
                        '      userGqlInfo {\n'
                        '        id\n'
                        '        username\n'
                        '        email\n'
                        '        firstname\n'
                        '        lastname\n'
                        '        avatar\n'
                        '        mood\n'
                        '        name\n'
                        '        role\n'
                        '        status\n'
                        '        timezone\n'
                        '        phone\n'
                        '        address\n'
                        '        location\n'
                        '        createdAt\n'
                        '        updatedAt\n'
                        '        owner\n'
                        '      }\n'
                        '      slackTeam {\n'
                        '        id\n'
                        '        owner\n'
                        '        teamId\n'
                        '        teamName\n'
                        '        slackAppId\n'
                        '        botId\n'
                        '        botToken\n'
                        '        botScope\n'
                        '        enterprise\n'
                        '      }\n'
                        '      channelsEnabled {\n'
                        '        nextToken\n'
                        '      }\n'
                        '    }\n'
                        '  }\n',
 'updatesshtabs': '\n'
                  '  mutation UpdateSshTabs($input: UpdateSshTabsInput!) {\n'
                  '    updateSshTabs(input: $input) {\n'
                  '      id\n'
                  '      investigationId\n'
                  '      host\n'
                  '      author\n'
                  '      userName\n'
                  '      createdAt\n'
                  '      updatedAt\n'
                  '    }\n'
                  '  }\n',
 'updatestash': '\n'
                '  mutation UpdateStash($input: UpdateStashInput!) {\n'
                '    updateStash(input: $input) {\n'
                '      id\n'
                '      Key\n'
                '      Value\n'
                '      createdAt\n'
                '      updatedAt\n'
                '      author\n'
                '      scope\n'
                '      PeopleCanView\n'
                '      PeopleCanAccess\n'
                '      GroupsCanView\n'
                '      GroupsCanAccess\n'
                '    }\n'
                '  }\n',
 'updatestate': '\n'
                '  mutation UpdateState($input: UpdateStateInput!) {\n'
                '    updateState(input: $input) {\n'
                '      id\n'
                '      name\n'
                '      createdAt\n'
                '      updatedAt\n'
                '      author\n'
                '      lastState\n'
                '      investigationId\n'
                '      investigation {\n'
                '        id\n'
                '        title\n'
                '        from\n'
                '        createdAt\n'
                '        currentState\n'
                '        HumanID\n'
                '        currentStateID\n'
                '        severity\n'
                '        priority\n'
                '        location\n'
                '        channelId\n'
                '        updatedAt\n'
                '        resolvedTime\n'
                '        resolvedComment\n'
                '        Symptoms\n'
                '        meetingType\n'
                '        meetingId\n'
                '      }\n'
                '    }\n'
                '  }\n',
 'updatesummaryinvestigation': '\n'
                               '  mutation UpdateSummaryInvestigation(\n'
                               '    $input: UpdateSummaryInvestigationInput!\n'
                               '  ) {\n'
                               '    updateSummaryInvestigation(input: $input) '
                               '{\n'
                               '      id\n'
                               '      createdAt\n'
                               '      updatedAt\n'
                               '      resolvedTime\n'
                               '      OriginalID\n'
                               '      title\n'
                               '      HumanID\n'
                               '      Commands\n'
                               '      InvestigationEvents\n'
                               '      CompleteInvestigationEvents\n'
                               '      Participants\n'
                               '      Comments\n'
                               '      Pins\n'
                               '      AvailableRunbooks\n'
                               '      UsedRunbooks\n'
                               '      Hints\n'
                               '      Symptoms\n'
                               '      owner\n'
                               '    }\n'
                               '  }\n',
 'updatetenantcustomer': '\n'
                         '  mutation UpdateTenantCustomer($input: '
                         'UpdateTenantCustomerInput!) {\n'
                         '    updateTenantCustomer(input: $input) {\n'
                         '      label\n'
                         '      impactLabels\n'
                         '      createdAt\n'
                         '      updatedAt\n'
                         '      customerName\n'
                         '      email\n'
                         '      phoneno\n'
                         '      SLAType\n'
                         '      city\n'
                         '      state\n'
                         '      contry\n'
                         '      zipcode\n'
                         '    }\n'
                         '  }\n',
 'updatetranscriptionrecords': '\n'
                               '  mutation UpdateTranscriptionRecords(\n'
                               '    $input: UpdateTranscriptionRecordsInput!\n'
                               '  ) {\n'
                               '    updateTranscriptionRecords(input: $input) '
                               '{\n'
                               '      id\n'
                               '      investigationId\n'
                               '      createdAt\n'
                               '      updatedAt\n'
                               '      spokenBy\n'
                               '      content\n'
                               '    }\n'
                               '  }\n',
 'updateusedtogenhintalready': '\n'
                               '  mutation UpdateUsedToGenHintAlready(\n'
                               '    $input: UpdateUsedToGenHintAlreadyInput!\n'
                               '  ) {\n'
                               '    updateUsedToGenHintAlready(input: $input) '
                               '{\n'
                               '      id\n'
                               '      createdAt\n'
                               '      updatedAt\n'
                               '      investigationId\n'
                               '      commands\n'
                               '      text\n'
                               '      investigation {\n'
                               '        id\n'
                               '        title\n'
                               '        from\n'
                               '        createdAt\n'
                               '        currentState\n'
                               '        HumanID\n'
                               '        currentStateID\n'
                               '        severity\n'
                               '        priority\n'
                               '        location\n'
                               '        channelId\n'
                               '        updatedAt\n'
                               '        resolvedTime\n'
                               '        resolvedComment\n'
                               '        Symptoms\n'
                               '        meetingType\n'
                               '        meetingId\n'
                               '      }\n'
                               '    }\n'
                               '  }\n',
 'updateuser': '\n'
               '  mutation UpdateUser($input: UpdateUserInput!) {\n'
               '    updateUser(input: $input) {\n'
               '      id\n'
               '      username\n'
               '      email\n'
               '      firstname\n'
               '      lastname\n'
               '      avatar\n'
               '      mood\n'
               '      name\n'
               '      role\n'
               '      status\n'
               '      timezone\n'
               '      phone\n'
               '      address\n'
               '      location\n'
               '      chatList {\n'
               '        nextToken\n'
               '      }\n'
               '      messages {\n'
               '        nextToken\n'
               '      }\n'
               '      createdAt\n'
               '      updatedAt\n'
               '      owner\n'
               '    }\n'
               '  }\n',
 'updateuseractivity': '\n'
                       '  mutation UpdateUserActivity($input: '
                       'UpdateUserActivityInput!) {\n'
                       '    updateUserActivity(input: $input) {\n'
                       '      id\n'
                       '      userID\n'
                       '      status\n'
                       '      investigationID\n'
                       '      createdAt\n'
                       '      updatedAt\n'
                       '      investigation {\n'
                       '        id\n'
                       '        title\n'
                       '        from\n'
                       '        createdAt\n'
                       '        currentState\n'
                       '        HumanID\n'
                       '        currentStateID\n'
                       '        severity\n'
                       '        priority\n'
                       '        location\n'
                       '        channelId\n'
                       '        updatedAt\n'
                       '        resolvedTime\n'
                       '        resolvedComment\n'
                       '        Symptoms\n'
                       '        meetingType\n'
                       '        meetingId\n'
                       '      }\n'
                       '      user {\n'
                       '        id\n'
                       '        username\n'
                       '        email\n'
                       '        firstname\n'
                       '        lastname\n'
                       '        avatar\n'
                       '        mood\n'
                       '        name\n'
                       '        role\n'
                       '        status\n'
                       '        timezone\n'
                       '        phone\n'
                       '        address\n'
                       '        location\n'
                       '        createdAt\n'
                       '        updatedAt\n'
                       '        owner\n'
                       '      }\n'
                       '    }\n'
                       '  }\n',
 'updateusersetting': '\n'
                      '  mutation UpdateUserSetting($input: '
                      'UpdateUserSettingInput!) {\n'
                      '    updateUserSetting(input: $input) {\n'
                      '      id\n'
                      '      userId\n'
                      '      owner\n'
                      '      createdAt\n'
                      '      updatedAt\n'
                      '      labels {\n'
                      '        nextToken\n'
                      '      }\n'
                      '      value\n'
                      '      url\n'
                      '      name\n'
                      '      type\n'
                      '      showWelcomeNext\n'
                      '      showWelcomeSkip\n'
                      '      showWelcomeRemind\n'
                      '      welcomeData\n'
                      '    }\n'
                      '  }\n',
 'updateusersettinglabellink': '\n'
                               '  mutation UpdateUserSettingLabelLink(\n'
                               '    $input: UpdateUserSettingLabelLinkInput!\n'
                               '  ) {\n'
                               '    updateUserSettingLabelLink(input: $input) '
                               '{\n'
                               '      id\n'
                               '      userSettingId\n'
                               '      userSetting {\n'
                               '        id\n'
                               '        userId\n'
                               '        owner\n'
                               '        createdAt\n'
                               '        updatedAt\n'
                               '        value\n'
                               '        url\n'
                               '        name\n'
                               '        type\n'
                               '        showWelcomeNext\n'
                               '        showWelcomeSkip\n'
                               '        showWelcomeRemind\n'
                               '        welcomeData\n'
                               '      }\n'
                               '      labelID\n'
                               '      label {\n'
                               '        id\n'
                               '        name\n'
                               '        color\n'
                               '        type\n'
                               '      }\n'
                               '      type\n'
                               '    }\n'
                               '  }\n'}
